import React, { Component } from 'react'
import PropTypes from 'prop-types'
import OutsideClickHandler from 'react-outside-click-handler'
import Input from './Input'

const propTypes = {
    activeIndexOnInputChange: PropTypes.number,
    addClearInput: PropTypes.bool,
    autoFocus: PropTypes.bool,
    book: PropTypes.bool,
    clearOnSelect: PropTypes.bool,
    clearOnSubmit: PropTypes.bool,
    defaultActiveIndex: PropTypes.number,
    defaultValue: PropTypes.string,
    disabled: PropTypes.bool,
    hideDropdownOnSubmit: PropTypes.bool,
    hideLabel: PropTypes.bool,
    hideResultsTopBorder: PropTypes.bool,
    id: PropTypes.string,
    inline: PropTypes.bool,
    inputBorderless: PropTypes.bool,
    inputFocusBorderless: PropTypes.bool,
    inputOverflowEllipsis: PropTypes.bool,
    inputRef: PropTypes.func,
    inputRemoveMargins: PropTypes.bool,
    invalid: PropTypes.bool,
    inverse: PropTypes.bool,
    loading: PropTypes.bool,
    label: PropTypes.string,
    labelDescription: PropTypes.string,
    large: PropTypes.bool,
    maxResults: PropTypes.number,
    name: PropTypes.string,
    noResultsLabel: PropTypes.oneOfType([PropTypes.string, PropTypes.symbol]),
    onBlur: PropTypes.func,
    onCancel: PropTypes.func,
    onChange: PropTypes.func,
    onFocus: PropTypes.func,
    onSelect: PropTypes.func,
    onSubmit: PropTypes.func,
    placeholder: PropTypes.string,
    prefix: PropTypes.symbol,
    results: PropTypes.arrayOf(PropTypes.object),
    resultsBorderless: PropTypes.bool,
    resultsMaxHeight: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
    resultsPosition: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
    resultsWidth: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
    scrollResults: PropTypes.bool,
    showFakeValuePlaceholder: PropTypes.bool,
    small: PropTypes.bool,
    subResultPaddingUnits: PropTypes.number,
    underlineFocus: PropTypes.bool,
};

class Autocomplete extends Component {
    constructor(props) {
        super(props);
        this.state = {
            activeIndex: props.defaultActiveIndex || -1,
            areResultsVisible: false,
            lastEventType: null,
            value: ''
        }
    }

    render() {
        const {
            activeIndexOnInputChange,
            addClearInput,
            autoFocus,
            book,
            clearOnSelect,
            clearOnSubmit,
            defaultActiveIndex,
            defaultValue,
            disabled,
            hideDropdownOnSubmit,
            hideLabel,
            hideResultsTopBorder,
            id,
            inline,
            inputBorderless,
            inputFocusBorderless,
            inputOverflowEllipsis,
            inputRef,
            inputRemoveMargins,
            invalid,
            inverse,
            loading,
            label,
            labelDescription,
            large,
            maxResults,
            name,
            noResultsLabel,
            onBlur,
            onCancel,
            onChange,
            onFocus,
            onSelect,
            onSubmit,
            placeholder,
            prefix,
            results,
            resultsBorderless,
            resultsMaxHeight,
            resultsPosition,
            resultsWidth,
            scrollResults,
            showFakeValuePlaceholder,
            small,
            subResultPaddingUnits,
            underlineFocus,
        } = this.props;

        return (
            <OutsideClickHandler>
                <Input
                    autoComplete="off"
                    autoFocus={autoFocus}
                    book={book}
                    borderless={inputBorderless}
                    disabled={disabled}
                    //errorMessage={errorMessage}
                    focusBorderless={inputFocusBorderless}
                    hideLabel={hideLabel}
                    id={id}
                    inline={inline}
                    inputRef={inputRef}
                    invalid={invalid}
                    inverse={inverse}
                    label={label}
                    labelDescription={labelDescription}
                    large={large}
                    name={name}
                    //onBlur={onBlur}
                    //onChange={onChange}
                    //onClear={onClear}
                    //onFocus={onFocus}
                    //onKeyDown={onKeyDown}
                    placeholder={placeholder}
                    prefix={prefix}
                    //refForFocus={refForFocus}
                    removeMargins={inputRemoveMargins}
                    showFakeValuePlaceholder={showFakeValuePlaceholder}
                    showOverflowEllipsis={inputOverflowEllipsis}
                    small={small}
                    type="text"
                    underlineFocus={underlineFocus}
                    value={this.state.value}
                />
            </OutsideClickHandler>
        )
    }
}

Autocomplete.propTypes = propTypes;

export { Autocomplete }
