import React from 'react'
import PropTypes from 'prop-types'
import { withStyles } from '../helpers/withStyles'
import Shimmer from './Shimmer'
import { withStylesPropTypes } from 'react-with-styles'

const propTypes = {
    ...withStylesPropTypes,
    inline: PropTypes.bool,
    large: PropTypes.bool,
    loading: PropTypes.bool,
    micro: PropTypes.bool,
    small: PropTypes.bool,
    source: PropTypes.string,
    square: PropTypes.string,
}

const Avatar = ({ css, inline, large, loading, micro, small, source, square, styles }) => {
    return (
        <div
            {...css(
                styles.avatar,
                inline && styles.avatar_inline,
                large && styles.avatar_large,
                micro && styles.avatar_micro,
                small && styles.avatar_small,
                square && styles.avatar_square,
                { backgroundImage: `url(${source})` }
            )}
        >
            { loading && <Shimmer width="100%" height="100%" /> }
        </div>
    )
}

Avatar.propTypes = propTypes

const AvatarWithStyles = withStyles(({ color, units, radius }) => ({
    avatar: {
        borderRadius: '50%',
        overflow: 'hidden',
        width: units(3.5),
        height: units(3.5),
        backgroundSize: 'cover',
        backgroundColor: color.gray,
        backgroundPosition: 'center'
    },

    avatar_inline: {
        display: 'inline-block'
    },

    avatar_micro: {
        width: units(1.5),
        height: units(1.5),
    },

    avatar_small: {
        width: units(2.5),
        height: units(2.5),
    },

    avatar_large: {
        width: units(5),
        height: units(5)
    },

    avatar_square: {
        borderRadius: radius
    }

}))(Avatar)

export default AvatarWithStyles
