import React from 'react'
import PropTypes from 'prop-types'
import Transition from 'react-transition-group/Transition'
import { withStyles } from '../helpers/withStyles'
import { Responsive } from './Responsive'
import { withStylesPropTypes } from 'react-with-styles'

const propTypes = {
    ...withStylesPropTypes,
    showFor: PropTypes.oneOf(['small', 'medium', 'large', 'xlarge']),
    hideFor: PropTypes.oneOf(['small', 'medium', 'large', 'xlarge']),
    global: PropTypes.bool,
    primary: PropTypes.bool,
    visible: PropTypes.bool,
    onClick: PropTypes.func,
    onClose: PropTypes.func,
};

const Blanket = ({ showFor, hideFor, global, visible, onClick, onClose, primary, styles, css }) => (
    <Transition
        in={visible}
        timeout={300}
        mountOnEnter
        unmountOnExit
        onEnter={node => node.scrollTop}
        onExited={() => onClose()}
    >
        {(state) => (
            <Responsive showFor={showFor} hideFor={hideFor}>
                <div
                    {...css(
                        styles.blanket,
                        global && styles.blanket_global,
                        primary && styles.blanket_primary,
                        (state === 'entering' || state === 'entered') && styles.blanket_entering,
                        (state === 'exiting' || state === 'exited') && styles.blanket_exiting,
                    )}
                    onClick={() => onClick && onClick()}
                />
            </Responsive>
        )}
    </Transition>
);

Blanket.propTypes = propTypes;

const BlanketWithStyles = withStyles(({ color }) =>({
    blanket: {
        width: '100%',
        height: '100%',
        position: 'fixed',
        top: 0,
        right: 0,
        bottom: 0,
        left: 0,
        zIndex: 99,
        background: color.white,
        opacity: 0.75,
        transition: 'opacity 300ms ease-out'
    },

    blanket_global: {
        zIndex: 101
    },

    blanket_primary: {
        background: color.primary
    },

    //transitions
    blanket_entering: {
        opacity: 0.75,
        transition: 'opacity 300ms ease-out'
    },

    blanket_exiting: {
        opacity: 0.01,
        transition: 'opacity 300ms ease-out'
    }

}))(Blanket);

export default BlanketWithStyles
