import React from 'react'
import PropTypes from 'prop-types'
import Loader from './Loader'
import Shimmer from './Shimmer'
import { withStyles } from '../helpers/withStyles'
import { withStylesPropTypes } from 'react-with-styles'

const propTypes = {
    ...withStylesPropTypes,
    disabled: PropTypes.bool,
    loading: PropTypes.bool,
    fullWidth: PropTypes.bool,
    block: PropTypes.bool,
    compact: PropTypes.bool,
    inverse: PropTypes.bool,
    large: PropTypes.bool,
    mono: PropTypes.bool,
    noSpacing: PropTypes.bool,
    soft: PropTypes.bool,
    primary: PropTypes.bool,
    rectangular: PropTypes.bool,
    secondary: PropTypes.bool,
    shade: PropTypes.bool,
    shimmer: PropTypes.bool,
    small: PropTypes.bool,
    short: PropTypes.bool,
    transparent: PropTypes.bool,
    type: PropTypes.string,
    underlined: PropTypes.bool,
    noBorder: PropTypes.bool,
    children: PropTypes.node
};

const defaultProps = {
    type: 'button'
}

const Button = (
    {
        styles,
        children,
        disabled,
        loading,
        fullWidth,
        block,
        compact,
        inverse,
        grouped,
        groupedFirst,
        groupedLast,
        large,
        mono,
        noSpacing,
        shade,
        soft,
        primary,
        rectangular,
        secondary,
        shimmer,
        short,
        small,
        transparent,
        type,
        underlined,
        noBorder,

        theme,
        css,

        href,
        noWrap,
        shadowLevel,
        ...props
    }
) => {
    return (
        <button
            {...props}
            {...css(
                styles.button,
                loading     && styles.button_loading,
                fullWidth   && styles.button_fullWidth,
                block       && styles.button_block,
                compact     && styles.button_compact,
                disabled    && styles.button_disabled,
                inverse     && styles.button_inverse,
                grouped     && styles.button_grouped,
                groupedFirst && styles.button_groupedFirst,
                groupedLast && styles.button_groupedLast,
                large       && styles.button_large,
                mono        && styles.button_mono,
                noSpacing   && styles.button_noSpacing,
                soft        && styles.button_soft,
                primary     && styles.button_primary,
                rectangular && styles.button_rectangular,
                secondary   && styles.button_secondary,
                shade       && styles.button_shade,
                short       && styles.button_short,
                small       && styles.button_small,
                transparent && styles.button_transparent,
                underlined  && styles.button_underlined,
                noBorder    && styles.button_noBorder,
            )}
            disabled={disabled || loading}
            type={type}
        >
            {
                loading && shimmer &&

                <div{...css(styles.shimmer)}>
                    <Shimmer height="100%" width="100%" />
                </div>
            }
            <div
                {...css(
                    styles.button__content,
                    loading && styles.button__content_loading,
                    fullWidth && styles.button__content_fullWidth,
                )}
            >
                { children }
            </div>
            { loading &&
                <div {...css(styles.button__loader, shimmer && styles.button__loader_shimmer)}>
                    { !shimmer && <Loader small primary={inverse && soft} secondary={secondary} mono={mono} /> }
                </div>
            }
        </button>
    )
};

Button.propTypes = propTypes;
Button.defaultProps = defaultProps;

const ButtonWithStyles = withStyles(({ color, breakpoint, units, font, fontSize, animation, radius }) => ({
    button: {
        appearance: 'none',
        borderWidth: 0,
        backgroundColor: color.secondary,
        height: units(2.5),
        //minWidth: units(2.5),
        paddingTop: units(0.25),
        paddingRight: units(1.25),
        paddingBottom: units(0.25),
        paddingLeft: units(1.25),
        borderRadius: radius,
        fontSize: units(0.95),
        color: color.white,
        outline: 0,
        position: 'relative',
        marginLeft: units(0.125),
        marginRight: units(0.125),
        marginBottom: units(0.5),
        fontWeight: 500,
        fontFamily: font.default,
        cursor: 'pointer',
        boxSizing: 'border-box',
        overflow: 'hidden',

        ':hover': {
            backgroundColor: color.secondarySaturated
        },

        ':active': {
            backgroundColor: color.secondaryDarker
        }
    },

    button_soft: {
        backgroundColor: color.blueGrayLighter,
        color: color.primary,

        ':hover': {
            backgroundColor: color.blueGrayLight
        },

        ':active': {
            backgroundColor: color.blueGray
        }
    },

    button_fullWidth: {
        width: '100%'
    },

    button_loading: {
        opacity: 1,
        pointerEvents: 'none'
    },

    button_block: {
        width: '100%',
        textAlign: 'left',
        marginRight: 0,
        marginLeft: 0,
    },

    button_compact: {
        paddingRight: units(0.75),
        paddingLeft: units(0.75),
    },

    button_shade: {
        background: color.shadowWeakest,

        ':hover': {
            background: color.shadowWeaker
        },

        ':active': {
            background: color.shadowWeak
        },
    },

    button_short: {
        height: units(2)
    },

    button_underlined: {
        borderBottomWidth: 1,
        borderBottomColor: color.primary,
        borderBottomStyle: 'solid'
    },

    button_grouped: {
        marginRight: .5,
        marginBottom: 0,
        marginLeft: .5,
    },

    button_groupedFirst: {
        borderRadius: `${radius}px 0 0 ${radius}px`,
        marginLeft: 0,
    },

    button_groupedLast: {
        borderRadius: `0 ${radius}px ${radius}px 0`,
        marginRight: 0
    },

    button_disabled: {
        opacity: .5,
        pointerEvents: 'none'
    },

    button_mono: {
        backgroundColor: color.transparent,
        borderColor: color.black,
        borderWidth: 1,
        borderStyle: 'solid',
        color: color.black,

        ':hover': {
            background: 'none'
        },

        ':active': {
            backgroundColor: color.grayLighter
        }
    },

    button_noSpacing: {
        marginBottom: 0
    },

    button_primary: {
        backgroundColor: color.primary,

        ':hover': {
            background: color.primarySaturated
        },

        ':active': {
            background: color.primaryDarker
        }
    },

    button_secondary: {
        backgroundColor: color.transparent,
        borderColor: color.secondary,
        borderWidth: 1,
        borderStyle: 'solid',
        color: color.secondary,

        ':hover': {
            color: color.secondarySaturated,
            backgroundColor: color.grayLightest
        },

        ':active': {
            borderColor: color.secondaryDarker,
            backgroundColor: color.grayLighter
        }
    },

    button_inverse: {
        backgroundColor: color.white,
        color: color.primary,
        borderWidth: 0,

        ':hover': {
            backgroundColor: color.blueGrayLight
        },

        ':active': {
            backgroundColor: color.blueGray
        }
    },

    button_transparent: {
        backgroundColor: color.transparent,
        color: color.primary,

        ':hover': {
            background: color.shadowWeakest
        },

        ':active': {
            background: color.shadowWeaker
        }
    },

    button_rectangular: {
        borderRadius: 0
    },

    button_noBorder: {
        border: 'none',
        borderWidth: 0
    },

    button_small: {
        fontSize: fontSize.small.small,

        [breakpoint.large]: {
            fontSize: fontSize.large.small,
        }
    },

    button_large: {
        fontSize: fontSize.small.large,

        [breakpoint.large]: {
            fontSize: fontSize.large.large,
        }
    },

    button__content: {
        display: 'flex',
        alignItems: 'center',
        justifyContent: 'flex-start',
        opacity: 1,
        transition: 'opacity .2s',
        whiteSpace: 'nowrap',
        userSelect: 'none'
    },

    button__content_loading: {
        opacity: 0,
    },

    button__content_fullWidth: {
        justifyContent: 'center'
    },

    button__loader: {
        position: 'absolute',
        top: 0,
        right: 0,
        bottom: 0,
        left: 0,
        display: 'flex',
        alignItems: 'center',
        justifyContent: 'center'
    },

    shimmer: {
        position: 'absolute',
        width: '100%',
        height: '100%',
        top: 0,
        right: 0,
        bottom: 0,
        left: 0
    }

}))(Button);
export default ButtonWithStyles
