import React, { Children } from 'react'
import PropTypes from 'prop-types'
import { withStyles } from '../helpers/withStyles'
import { withStylesPropTypes } from 'react-with-styles'

const propTypes = {
    ...withStylesPropTypes,
    disabled: PropTypes.bool,
    loading: PropTypes.bool,
    fullWidth: PropTypes.bool,
    block: PropTypes.bool,
    compact: PropTypes.bool,
    inverse: PropTypes.bool,
    mono: PropTypes.bool,
    noSpacing: PropTypes.bool,
    soft: PropTypes.bool,
    primary: PropTypes.bool,
    rectangular: PropTypes.bool,
    secondary: PropTypes.bool,
    shade: PropTypes.bool,
    shimmer: PropTypes.bool,
    short: PropTypes.bool,
    transparent: PropTypes.bool,
    type: PropTypes.string,
    noBorder: PropTypes.bool,
    children: PropTypes.node
};

const defaultProps = {
    type: 'button'
}

const ButtonGroup = (
    {
        styles,
        children,
        disabled,
        loading,
        fullWidth,
        block,
        compact,
        inverse,
        grouped,
        groupedFirst,
        groupedLast,
        mono,
        noSpacing,
        shade,
        soft,
        primary,
        rectangular,
        secondary,
        shimmer,
        short,
        transparent,
        type,
        underlined,
        noBorder,

        theme,
        css,

        href,
        large,
        noWrap,
        shadowLevel,
        small,
        ...props
    }
) => {
    return (
        <div
            {...css(
                styles.buttonGroup,
                loading     && styles.button_loading,
                fullWidth   && styles.button_fullWidth,
                block       && styles.button_block,
                grouped     && styles.button_grouped,
                groupedFirst && styles.button_groupedFirst,
                groupedLast && styles.button_groupedLast,
                noSpacing   && styles.button_noSpacing,
            )}
        >
            {
                Children.map(children, (child, i) => {
                    const button = React.cloneElement(child, {
                        compact: compact,
                        disabled: disabled,
                        inverse: inverse,
                        rectangular: rectangular || (i > 0 && i < children.length - 1),
                        grouped: true,
                        groupedFirst: i === 0,
                        groupedLast: i === children.length - 1,
                        fullWidth: fullWidth,
                        mono: mono,
                        primary: primary,
                        secondary: secondary,
                        shade: shade,
                        short: short,
                        soft: soft,
                        transparent: transparent,
                        underlined: underlined
                    });

                    return fullWidth ? <div {...css(styles.buttonContainer)}>{ button }</div> : button
                })
            }
        </div>
    )
};

ButtonGroup.propTypes = propTypes;
ButtonGroup.defaultProps = defaultProps;

const ButtonGroupWithStyles = withStyles(({ color, units, font, animation, radius }) => ({
    buttonGroup: {
        marginBottom: units(0.5),
        boxSizing: 'border-box',
        display: 'flex'
    },

    button_soft: {
        backgroundColor: color.blueGrayLighter,
        color: color.primary,

        ':hover': {
            backgroundColor: color.blueGrayLight
        },

        ':active': {
            backgroundColor: color.blueGray
        }
    },

    button_fullWidth: {
        width: '100%'
    },

    button_loading: {
        opacity: 1,
        pointerEvents: 'none'
    },

    button_block: {
        width: '100%',
        textAlign: 'left',
        marginRight: 0,
        marginLeft: 0,
    },

    button_compact: {
        paddingRight: units(0.75),
        paddingLeft: units(0.75),
    },

    button_shade: {
        background: color.shadowWeakest,

        ':hover': {
            background: color.shadowWeaker
        },

        ':active': {
            background: color.shadowWeak
        },
    },

    button_short: {
        height: units(2)
    },

    button_grouped: {
        marginRight: 1,
        marginBottom: 0,
        marginLeft: 1
    },

    button_groupedFirst: {
        borderRadius: `0 0 ${radius}px ${radius}px`
    },

    button_disabled: {
        opacity: .5,
        pointerEvents: 'none'
    },

    button_mono: {
        backgroundColor: color.transparent,
        borderColor: color.black,
        borderWidth: 1,
        borderStyle: 'solid',
        color: color.black,

        ':hover': {
            background: 'none'
        },

        ':active': {
            backgroundColor: color.grayLighter
        }
    },

    button_noSpacing: {
        marginBottom: 0
    },

    button_primary: {
        backgroundColor: color.primary,

        ':hover': {
            background: color.primarySaturated
        },

        ':active': {
            background: color.primaryDarker
        }
    },

    button_secondary: {
        backgroundColor: color.transparent,
        borderColor: color.secondary,
        borderWidth: 1,
        borderStyle: 'solid',
        color: color.secondary,

        ':hover': {
            color: color.secondarySaturated,
            backgroundColor: color.grayLightest
        },

        ':active': {
            borderColor: color.secondaryDarker,
            backgroundColor: color.grayLighter
        }
    },

    button_inverse: {
        backgroundColor: color.white,
        color: color.primary,
        borderWidth: 0,

        ':hover': {
            backgroundColor: color.blueGrayLight
        },

        ':active': {
            backgroundColor: color.blueGray
        }
    },

    button_transparent: {
        backgroundColor: color.transparent,
        color: color.primary,

        ':hover': {
            background: color.shadowWeakest
        },

        ':active': {
            background: color.shadowWeaker
        }
    },

    button_rectangular: {
        borderRadius: 0
    },

    button_noBorder: {
        border: 'none',
        borderWidth: 0
    },

    button__content: {
        display: 'flex',
        alignItems: 'center',
        justifyContent: 'flex-start',
        opacity: 1,
        transition: 'opacity .2s',
        whiteSpace: 'nowrap',
        userSelect: 'none'
    },

    button__content_loading: {
        opacity: 0,
    },

    button__content_fullWidth: {
        justifyContent: 'center'
    },

    button__loader: {
        position: 'absolute',
        top: 0,
        right: 0,
        bottom: 0,
        left: 0,
        display: 'flex',
        alignItems: 'center',
        justifyContent: 'center'
    },

    buttonContainer: {
        flex: 1
    },

    shimmer: {
        position: 'absolute',
        width: '100%',
        height: '100%',
        top: 0,
        right: 0,
        bottom: 0,
        left: 0
    }

}))(ButtonGroup);
export default ButtonGroupWithStyles
