import React from 'react'
import PropTypes from 'prop-types'
import { withStyles } from '../helpers/withStyles'
import { withStylesPropTypes } from 'react-with-styles'
import theme from '../themes/CinnectaTheme'

const propTypes = {
    ...withStylesPropTypes,
    children: PropTypes.any,
    size: PropTypes.number,
    mediumSize: PropTypes.number,
    largeSize: PropTypes.number,
    xlargeSize: PropTypes.number,
    columns: PropTypes.number,
    columnsOnMedium: PropTypes.number,
    columnsOnLarge: PropTypes.number,
    columnsOnXlarge: PropTypes.number,
    fullHeight: PropTypes.bool,
    fullHeightOnMedium: PropTypes.bool,
    fullHeightOnLarge: PropTypes.bool,
    fullHeightOnXlarge: PropTypes.bool,
    microSpacing: PropTypes.bool,
    smallSpacing: PropTypes.bool,
    largeSpacing: PropTypes.bool,
    noSpacing: PropTypes.bool,
    verticalSpacing: PropTypes.bool,
    microVerticalSpacing: PropTypes.bool,
    smallVerticalSpacing: PropTypes.bool,
    largeVerticalSpacing: PropTypes.bool,
    auto: PropTypes.bool,
    autoOnMedium: PropTypes.bool,
    autoOnLarge: PropTypes.bool,
    autoOnXlarge: PropTypes.bool,
    relative: PropTypes.bool,
    shrink: PropTypes.bool,
    shrinkOnMedium: PropTypes.bool,
    shrinkOnLarge: PropTypes.bool,
    shrinkOnXlarge: PropTypes.bool,
    grow: PropTypes.bool,
    growOnMedium: PropTypes.bool,
    growOnLarge: PropTypes.bool,
    growOnXlarge: PropTypes.bool,
    order: PropTypes.number,
    maxWidth: PropTypes.number,
    minWidth: PropTypes.number,
    scroll: PropTypes.bool
};

const Cell = (
    {
        children,
        size,
        mediumSize,
        largeSize,
        xlargeSize,
        columns,
        columnsOnMedium,
        columnsOnLarge,
        columnsOnXlarge,
        fullHeight,
        fullHeightOnMedium,
        fullHeightOnLarge,
        fullHeightOnXlarge,
        microSpacing,
        smallSpacing,
        largeSpacing,
        noSpacing,
        verticalSpacing,
        microVerticalSpacing,
        smallVerticalSpacing,
        largeVerticalSpacing,
        auto,
        autoOnMedium,
        autoOnLarge,
        autoOnXlarge,
        relative,
        shrink,
        shrinkOnMedium,
        shrinkOnLarge,
        shrinkOnXlarge,
        grow,
        growOnMedium,
        growOnLarge,
        growOnXlarge,
        order,
        maxWidth,
        minWidth,
        scroll,

        css,
        styles
    }
) => {
    return (
        <div
            {...css(
                styles.cell,
                size && styles[`cell_${size}`],
                mediumSize && styles[`cell_medium_${mediumSize}`],
                largeSize && styles[`cell_large_${largeSize}`],
                xlargeSize && styles[`cell_xlarge_${xlargeSize}`],
                columns && styles[`cell_columns_${columns}`],
                columnsOnMedium && styles[`cell_columns_medium_${columnsOnMedium}`],
                columnsOnLarge && styles[`cell_columns_large_${columnsOnLarge}`],
                columnsOnXlarge && styles[`cell_columns_xlarge_${columnsOnXlarge}`],
                auto && styles.cell_auto,
                autoOnMedium && styles.cell_auto_medium,
                autoOnLarge && styles.cell_auto_large,
                autoOnXlarge && styles.cell_auto_xlarge,
                fullHeight && styles.cell_fullHeight,
                fullHeightOnMedium && styles.cell_fullHeight_medium,
                fullHeightOnLarge && styles.cell_fullHeight_large,
                fullHeightOnXlarge && styles.cell_fullHeight_xlarge,
                relative && styles.relative,
                shrink && styles.cell_shrink,
                shrinkOnMedium && styles.cell_shrink_medium,
                shrinkOnLarge && styles.cell_shrink_large,
                shrinkOnXlarge && styles.cell_shrink_xlarge,
                grow && styles.cell_grow,
                growOnMedium && styles.cell_grow_medium,
                growOnLarge && styles.cell_grow_large,
                growOnXlarge && styles.cell_grow_xlarge,
                microSpacing && styles.cell_microSpacing,
                smallSpacing && styles.cell_smallSpacing,
                largeSpacing && styles.cell_largeSpacing,
                verticalSpacing && styles.cell_verticalSpacing,
                microVerticalSpacing && styles.cell_verticalSpacing_micro,
                smallVerticalSpacing && styles.cell_verticalSpacing_small,
                largeVerticalSpacing && styles.cell_verticalSpacing_large,
                noSpacing && styles.cell_noSpacing,
                scroll && styles.cell_scroll,
                {
                    order: order,
                    maxWidth: maxWidth && maxWidth * theme.unit,
                    minWidth: minWidth && minWidth * theme.unit
                }
            )}
        >
            { children }
        </div>
    )
};

Cell.propTypes = propTypes;

const CellWithStyles = withStyles(({ breakpoint, gutter, columns }) => {
    let sizes = {};
    for(let size = 1; size <= columns; size++) {
        sizes[`cell_${size}`] = {
            width: `${(size / columns)*100}%`
        };

        sizes[`cell_medium_${size}`] = {
            [breakpoint.mediumAndAbove]: {
                width: `${(size / columns)*100}%`
            }
        };

        sizes[`cell_large_${size}`] = {
            [breakpoint.large]: {
                width: `${(size / columns)*100}%`
            }
        };

        sizes[`cell_xlarge_${size}`] = {
            [breakpoint.xlarge]: {
                width: `${(size / columns)*100}%`
            }
        };

        sizes[`cell_columns_${size}`] = {
            width: `${100 / size}%`
        };

        sizes[`cell_columns_medium_${size}`] = {
            [breakpoint.mediumAndAbove]: {
                width: `${100 / size}%`
            }
        };

        sizes[`cell_columns_large_${size}`] = {
            [breakpoint.large]: {
                width: `${100 / size}%`
            }
        };

        sizes[`cell_columns_xlarge_${size}`] = {
            [breakpoint.xlarge]: {
                width: `${100 / size}%`
            }
        };
    }

    return ({
        cell: {
            //display: 'flex',
            paddingLeft: gutter.small.regular.left,
            paddingRight: gutter.small.regular.right,
            boxSizing: 'border-box',

            [breakpoint.mediumAndAbove]: {
                paddingLeft: gutter.medium.regular.left,
                paddingRight: gutter.medium.regular.right,
            },

            [breakpoint.large]: {
                paddingLeft: gutter.large.regular.left,
                paddingRight: gutter.large.regular.right,
            },

            [breakpoint.xlarge]: {
                paddingLeft: gutter.xlarge.regular.left,
                paddingRight: gutter.xlarge.regular.right,
            }
        },

        cell_fullHeight: {
            height: '100%'
        },

        cell_fullHeight_medium: {
            [breakpoint.mediumAndAbove]: {
                height: '100%'
            }
        },

        cell_fullHeight_large: {
            [breakpoint.large]: {
                height: '100%'
            }
        },

        cell_fullHeight_xlarge: {
            [breakpoint.xlarge]: {
                height: '100%'
            }
        },

        cell_microSpacing: {
            paddingLeft: gutter.small.micro.left,
            paddingRight: gutter.small.micro.right,

            [breakpoint.mediumAndAbove]: {
                paddingLeft: gutter.medium.micro.left,
                paddingRight: gutter.medium.micro.right,
            },

            [breakpoint.large]: {
                paddingLeft: gutter.large.micro.left,
                paddingRight: gutter.large.micro.right,
            },

            [breakpoint.xlarge]: {
                paddingLeft: gutter.xlarge.micro.left,
                paddingRight: gutter.xlarge.micro.right,
            }
        },

        cell_smallSpacing: {
            paddingLeft: gutter.small.small.left,
            paddingRight: gutter.small.small.right,

            [breakpoint.mediumAndAbove]: {
                paddingLeft: gutter.medium.small.left,
                paddingRight: gutter.medium.small.right,
            },

            [breakpoint.large]: {
                paddingLeft: gutter.large.small.left,
                paddingRight: gutter.large.small.right,
            },

            [breakpoint.xlarge]: {
                paddingLeft: gutter.xlarge.small.left,
                paddingRight: gutter.xlarge.small.right,
            }
        },

        cell_largeSpacing: {
            paddingLeft: gutter.small.large.left,
            paddingRight: gutter.small.large.right,

            [breakpoint.mediumAndAbove]: {
                paddingLeft: gutter.medium.large.left,
                paddingRight: gutter.medium.large.right,
            },

            [breakpoint.large]: {
                paddingLeft: gutter.large.large.left,
                paddingRight: gutter.large.large.right,
            },

            [breakpoint.xlarge]: {
                paddingLeft: gutter.xlarge.large.left,
                paddingRight: gutter.xlarge.large.right,
            }
        },

        cell_verticalSpacing: {
            paddingTop: gutter.small.regular.top,
            paddingBottom: gutter.small.regular.bottom,

            [breakpoint.mediumAndAbove]: {
                paddingTop: gutter.medium.regular.top,
                paddingBottom: gutter.medium.regular.bottom,
            },

            [breakpoint.large]: {
                paddingTop: gutter.large.regular.top,
                paddingBottom: gutter.large.regular.bottom,
            },

            [breakpoint.xlarge]: {
                paddingTop: gutter.xlarge.regular.top,
                paddingBottom: gutter.xlarge.regular.bottom,
            }
        },

        cell_verticalSpacing_micro: {
            paddingTop: gutter.small.micro.top,
            paddingBottom: gutter.small.micro.bottom,

            [breakpoint.mediumAndAbove]: {
                paddingTop: gutter.medium.micro.top,
                paddingBottom: gutter.medium.micro.bottom,
            },

            [breakpoint.large]: {
                paddingTop: gutter.large.micro.top,
                paddingBottom: gutter.large.micro.bottom,
            },

            [breakpoint.xlarge]: {
                paddingTop: gutter.xlarge.micro.top,
                paddingBottom: gutter.xlarge.micro.bottom,
            }
        },

        cell_verticalSpacing_small: {
            paddingTop: gutter.small.small.top,
            paddingBottom: gutter.small.small.bottom,

            [breakpoint.mediumAndAbove]: {
                paddingTop: gutter.medium.small.top,
                paddingBottom: gutter.medium.small.bottom,
            },

            [breakpoint.large]: {
                paddingTop: gutter.large.small.top,
                paddingBottom: gutter.large.small.bottom,
            },

            [breakpoint.xlarge]: {
                paddingTop: gutter.xlarge.small.top,
                paddingBottom: gutter.xlarge.small.bottom,
            }
        },

        cell_verticalSpacing_large: {
            paddingTop: gutter.small.large.top,
            paddingBottom: gutter.small.large.bottom,

            [breakpoint.mediumAndAbove]: {
                paddingTop: gutter.medium.large.top,
                paddingBottom: gutter.medium.large.bottom,
            },

            [breakpoint.large]: {
                paddingTop: gutter.large.large.top,
                paddingBottom: gutter.large.large.bottom,
            },

            [breakpoint.xlarge]: {
                paddingTop: gutter.xlarge.large.top,
                paddingBottom: gutter.xlarge.large.bottom,
            }
        },

        cell_noSpacing: {
            paddingTop: 0,
            paddingRight: 0,
            paddingBottom: 0,
            paddingLeft: 0,

            [breakpoint.mediumAndAbove]: {
                paddingTop: 0,
                paddingRight: 0,
                paddingBottom: 0,
                paddingLeft: 0,
            },

            [breakpoint.large]: {
                paddingTop: 0,
                paddingRight: 0,
                paddingBottom: 0,
                paddingLeft: 0,
            },

            [breakpoint.xlarge]: {
                paddingTop: 0,
                paddingRight: 0,
                paddingBottom: 0,
                paddingLeft: 0,
            }
        },

        cell_auto: {
            flex: '1 1 0',
            width: 'auto'
        },

        cell_auto_medium: {
            [breakpoint.mediumAndAbove]: {
                flex: '1 1 0',
                width: 'auto'
            }
        },

        cell_auto_large: {
            [breakpoint.large]: {
                flex: '1 1 0',
                width: 'auto'
            }
        },

        cell_auto_xlarge: {
            [breakpoint.xlarge]: {
                flex: '1 1 0',
                width: 'auto'
            }
        },

        cell_shrink: {
            flex: '0 0 auto',
            width: 'auto',
        },

        cell_shrink_medium: {
            [breakpoint.mediumAndAbove]: {
                flex: '0 0 auto',
                width: 'auto',
            }
        },

        cell_shrink_large: {
            [breakpoint.large]: {
                flex: '0 0 auto',
                width: 'auto',
            }
        },

        cell_shrink_xlarge: {
            [breakpoint.xlarge]: {
                flex: '0 0 auto',
                width: 'auto',
            }
        },

        cell_grow: {
            flex: '1 0 auto',
            width: 'auto',
        },

        cell_grow_medium: {
            [breakpoint.mediumAndAbove]: {
                flex: '1 0 auto',
                width: 'auto',
            }
        },

        cell_grow_large: {
            [breakpoint.large]: {
                flex: '1 0 auto',
                width: 'auto',
            }
        },

        cell_grow_xlarge: {
            [breakpoint.xlarge]: {
                flex: '1 0 auto',
                width: 'auto',
            }
        },

        cell_scroll: {
            overflow: 'auto'
        },

        relative: {
            position: 'relative'
        },

        ...sizes,
    })
}, { flushBefore: true })(Cell);

export default CellWithStyles
