import React from 'react'
import PropTypes from 'prop-types'
import Label from './Label'
import CheckboxOnly from './CheckboxOnly'
import Text from './Text'
import { withStyles } from '../helpers/withStyles'
import { withStylesPropTypes } from 'react-with-styles'

const propTypes = {
    ...withStylesPropTypes,
    checked: PropTypes.bool,
    disabled: PropTypes.bool,
    id: PropTypes.string,
    invalid: PropTypes.bool,
    label: PropTypes.oneOfType([PropTypes.string, PropTypes.object]),
    name: PropTypes.string,
    onBlur: PropTypes.func,
    onChange: PropTypes.func,
    onFocus: PropTypes.func,
    pullRight: PropTypes.bool,
    refForFocus: PropTypes.func,
    subtitle: PropTypes.string,
};

const defaultProps = {
    label: '',
    radioButton: false
};

const Checkbox = (
    {
        checked,
        css,
        disabled,
        id,
        invalid,
        label,
        name,
        onBlur,
        onChange,
        onFocus,
        pullRight,
        refForFocus,
        styles,
        subtitle
    }
) => {
    return (
        <Label htmlFor={id}>
            <div
                {...css(
                    styles.column,
                    pullRight && styles.pullRight,
                )}
            >
                <CheckboxOnly
                    id={id}
                    checked={checked}
                    disabled={disabled}
                    invalid={invalid}
                    name={name}
                    onBlur={onBlur}
                    onChange={onChange}
                    onFocus={onFocus}
                />
            </div>
            <div
                {...css(
                    styles.column,
                    pullRight ? styles.marginRight : styles.spacing,
                )}
            >
                <div
                    {...css(
                        styles.checkbox__label,
                    )}
                >
                    {
                        typeof label === 'string' ?
                            <Text disabled={disabled}>{ label }</Text>
                            :
                            label
                    }
                </div>
                { subtitle && checked && <div {...css(styles.subtitle)}><Text small>{ subtitle }</Text></div> }
            </div>
        </Label>
    )
};

Checkbox.propTypes = propTypes;
Checkbox.defaultProps = defaultProps;

const CheckboxWithStyles = withStyles(({ units, color, font, fontSize, weight, lineHeight, breakpoint }) => ({
    checkbox: {

    },

    column: {
        display: 'table-cell',
        verticalAlign: 'top',
        whiteSpace: 'normal'
    },

    checkbox__label: {
        color: color.grayDarker,
        cursor: 'pointer',
        display: 'inline-block',
        wordWrap: 'break-word',
        letterSpacing: 'normal',
        fontFamily: font.default,
        fontWeight: weight.normal,
        fontSize: fontSize.small.regular,
        lineHeight: lineHeight.regular,

        [breakpoint.large]: {
            fontSize: fontSize.large.regular
        }
    },

    spacing: {
        paddingLeft: 12,
    },

    marginRight: {
        marginRight: 32,
    },

    pullRight: {
        float: 'right'
    },

    subtitle: {
        paddingTop: 2,
    }
}))(Checkbox);

export default CheckboxWithStyles
