import React from 'react'
import PropTypes from 'prop-types'
import { withStyles } from '../helpers/withStyles'
import { withStylesPropTypes } from 'react-with-styles'

const propTypes = {
    ...withStylesPropTypes,
    checked: PropTypes.bool,
    disabled: PropTypes.bool,
    id: PropTypes.string,
    invalid: PropTypes.bool,
    name: PropTypes.string,
    onBlur: PropTypes.func,
    onChange: PropTypes.func,
    onFocus: PropTypes.func,
    refForFocus: PropTypes.func,
};

const CheckboxOnly = (
    {
        checked,
        css,
        disabled,
        id,
        invalid,
        name,
        onBlur,
        onChange,
        onFocus,
        refForFocus,
        styles,
    }
) => {
    return (
        <div {...css(styles.container)}>
            <div {...css(
                styles.checkbox,
                disabled && styles.checkbox_disabled,
                invalid && styles.checkbox_invalid,
            )}>
                <input
                    {...css(styles.checkbox__input)}
                    type="checkbox"
                    id={id}
                    name={name}
                    checked={checked}
                    disabled={disabled}
                    aria-invalid={invalid}
                    onBlur={onBlur}
                    onChange={onChange}
                    onFocus={onFocus}
                />
                <div {...css(styles.checkbox__markContainer)} data-fake-checkbox={!invalid && !disabled}>
                    {
                        checked &&
                        <div {...css(styles.checkbox__checkMark)}>
                            <svg {...css(styles.checkbox__checkMark__icon)} xmlns="http://www.w3.org/2000/svg" viewBox="0 0 54.19 42.05">
                                <path d="M48,0a6,6,0,0,0-4.12,1.81c-9.36,9.38-16.58,17.25-25.16,26L10,20.47a6,6,0,0,0-8,8.92l.28.23,13,11a6,6,0,0,0,8.13-.34c10.79-10.81,18.46-19.43,29-30A6,6,0,0,0,48,0Z"/>
                            </svg>
                        </div>
                    }
                </div>
            </div>
        </div>
    )
};

CheckboxOnly.propTypes = propTypes;

const CheckboxOnlyWithStyles = withStyles(({ units, color, input }) => ({
    container: {
        display: 'inline-block',
        position: 'relative',
        cursor: 'pointer',
        overflow: 'hidden',
        borderRadius: input.checkbox.borderRadius,
        marginTop: 2,

        ':focus-within': {
            boxShadow: `0 0 2px ${color.secondary}`
        }
    },

    checkbox: {
        width: input.checkbox.size,
        height: input.checkbox.size,
        background: input.checkbox.background,
        textAlign: 'center',
        ...input.checkbox.border,
        boxSizing: 'border-box'
    },

    checkbox_disabled: {
        background: input.checkbox.disabled.background,
        ...input.checkbox.disabled.border
    },

    checkbox_invalid: {
        background: input.checkbox.invalid.background,
        ...input.checkbox.invalid.border
    },

    checkbox__input: {
        width: '100%',
        height: '100%',
        margin: 0,
        padding: 0,
        opacity: 0,
        position: 'absolute',
        top: 0,
        right: 0,
        bottom: 0,
        left: 0,

        ':focus + [data-fake-checkbox]': {
            zIndex: 1,
            borderWidth: 1,
            borderStyle: 'solid',
            borderColor: color.secondary,
            boxSizing: 'border-box'
        },
    },

    checkbox__markContainer: {
        display: 'flex',
        position: 'absolute',
        width: '100%',
        height: '100%',
        top: 0,
        right: 0,
        bottom: 0,
        left: 0,
        alignItems: 'center',
        justifyContent: 'center',
        borderRadius: input.checkbox.borderRadius,
    },

    checkbox__checkMark: {
        background: color.secondary,
        width: '100%',
        height: '100%',
        display: 'flex',
        alignItems: 'center',
        justifyContent: 'center'
    },

    checkbox__checkMark__icon: {
        fill: color.white,
        width: '60%',
    }
}))(CheckboxOnly);

export default CheckboxOnlyWithStyles
