import React from 'react'
import PropTypes from 'prop-types'
import { withStylesPropTypes } from 'react-with-styles'
import { withStyles } from '../helpers/withStyles'

const propTypes = {
    ...withStylesPropTypes,
    children: PropTypes.any.isRequired,
    disabled: PropTypes.bool,
    inline: PropTypes.bool,
    inverse: PropTypes.bool,
    onClick: PropTypes.func,
    rectangular: PropTypes.bool
}

const Clickable = ({ children, css, disabled, inline, inverse, onClick, rectangular, styles }) => {
    return (
        inline ?
            <span
                onClick={onClick}
                {...css(
                    styles.clickable,
                    disabled && styles.clickable_disabled,
                    inverse && styles.clickable_inverse,
                    rectangular && styles.clickable_rectangular
                )}
            >
                { children }
            </span>
        :
            <div
                onClick={onClick}
                {...css(
                    styles.clickable,
                    disabled && styles.clickable_disabled,
                    inverse && styles.clickable_inverse,
                    rectangular && styles.clickable_rectangular
                )}
            >
                { children }
            </div>
    )
}

Clickable.propTypes = propTypes;

const ClickableWithStyles = withStyles(({ color, radius }) => ({
    clickable: {
        cursor: 'pointer',
        borderRadius: radius,

        ':hover': {
            background: color.shadowWeakest
        },

        ':active': {
            background: color.shadowWeaker
        }
    },

    clickable_disabled: {
        pointerEvents: 'none',
        opacity: 0.5
    },

    clickable_inverse: {
        ':hover': {
            background: color.fogWeakest
        },

        ':active': {
            background: color.fogWeaker
        }
    },

    clickable_rectangular: {
        borderRadius: 0
    }
}))(Clickable)

export default ClickableWithStyles