import React, { Component } from 'react'
import { withStyles } from '../helpers/withStyles'
import PageHeader from './PageHeader'
import Wrapper from './Wrapper'
import Spacing from './Spacing'
import Grid from './Grid'
import Cell from './Cell'
import Text from './Text'
import Icon from './Icon'
import FlatButton from './FlatButton'

class ConfigurationBox extends Component {

    render() {
        const { actions, children, closable, css, description, header, onClose, styles, title } = this.props;

        return (
            <div {...css(styles.configurationBox)}>
                <div {...css(styles.configurationBox__header)}>
                    <Grid center>
                        <Cell auto noSpacing>
                            <PageHeader
                                title={title}
                                description={description}
                                level={2}
                                removeMargin
                                removeDescriptionSpacing={description != null}
                            >
                                { actions }
                            </PageHeader>
                        </Cell>
                        {
                            closable &&

                            <Cell shrink noSpacing>
                                <div {...css(styles.closeButtonContainer)}>
                                    <FlatButton
                                        transparent
                                        icon={<Icon name="error" large />}
                                        onClick={() => onClose && onClose()}
                                    />
                                </div>
                            </Cell>
                        }
                    </Grid>
                </div>
                <div {...css(styles.configurationBox__body)}>
                    {
                        header && Array.isArray(header) && header.length > 0 &&

                        <div {...css(styles.configurationBox__header)}>
                            <Grid resetSpacing>
                                { header.map((headerItem, count) => {
                                    return (
                                        <Cell size={12} key={count} shrinkOnMedium>
                                            <div
                                                {...css(
                                                    styles.configurationBox__header__item,
                                                    styles.padded,
                                                    count + 1 < header.length && styles.borderRight
                                                )}
                                            >
                                                <Text bold>{ headerItem.label }</Text>
                                                <Text large>{ headerItem.content }</Text>
                                            </div>
                                        </Cell>
                                    )}
                                )}
                            </Grid>
                        </div>
                    }
                    <Spacing top={2}>
                        <Wrapper>
                            { children }
                        </Wrapper>
                    </Spacing>
                </div>
            </div>
        )
    }
}

const ConfigurationBoxWithStyles = withStyles(({ color, units, radius, font, breakpoint }) => ({
    configurationBox: {
        display: 'flex',
        flexDirection: 'column',
        height: '100%',
        fontFamily: font.default,
    },

    configurationBox__header: {
        paddingRight: units(1.5),
        paddingLeft: units(1.5),
        borderBottomWidth: 1,
        borderBottomColor: color.blueGrayLight,
        borderBottomStyle: 'solid',
        background: color.white,

        [breakpoint.large]: {
            paddingRight: units(3),
            paddingLeft: units(3),
        }
    },

    configurationBox__header__item: {
        paddingRight: units(2)
    },

    padded: {
        paddingTop: units(.5),
        paddingBottom: units(.5),

        [breakpoint.mediumAndAbove]: {
            paddingTop: units(1),
            paddingBottom: units(1),
        }
    },

    borderRight: {
        [breakpoint.mediumAndAbove]: {
            borderRightWidth: 1,
            borderRightColor: color.blueGrayLight,
            borderRightStyle: 'solid',
        }
    },

    configurationBox__body: {
        flex: 1,
        background: color.blueGrayLightest,
        overflow: 'auto',
        paddingBottom: units(4)
    },

    configurationBox__bullet: {
        width: 6,
        height: 6,
        background: color.grayDarker,
        borderRadius: '50%',
        marginTop: 8
    },

    closeButtonContainer: {
        position: 'absolute',
        right: units(1),
        top: units(1),

        [breakpoint.mediumAndAbove]: {
            position: 'static',
            borderLeftWidth: 1,
            borderLeftColor: color.blueGray,
            borderLeftStyle: 'solid',
            marginLeft: 16,
            paddingLeft: 8,
        }
    }
}))(ConfigurationBox);

export default ConfigurationBoxWithStyles
