import React, { Component } from 'react'
import PropTypes from 'prop-types'
import { withStyles } from '../helpers/withStyles'
import Spacing from './Spacing'
import Text from './Text'
import Title from './Title'
import Icon from './Icon'
import { withStylesPropTypes } from 'react-with-styles'

const propTypes = {
    ...withStylesPropTypes,
    after: PropTypes.object,
    before: PropTypes.object,
    children: PropTypes.any.isRequired,
    description: PropTypes.string,
    done: PropTypes.bool,
    errorMessage: PropTypes.string,
    invalid: PropTypes.bool,
    title: PropTypes.string,
};

class ConfigurationItem extends Component {
    render() {
        const { after, before, children, css, description, done, errorMessage, invalid, styles, title } = this.props;

        return (
            <div {...css(styles.configurationItem)}>
                { before }
                <div {...css(styles.configurationItem__content)}>
                    <Spacing bottom={1}>
                        <Title noSpacing light level={3}>
                            { title }
                            {
                                (done || invalid) &&
                                <div
                                    {...css(
                                        styles.statusLabel,
                                        done && styles.statusLabel_done,
                                        invalid && styles.statusLabel_error
                                    )}
                                >
                                    <Icon micro inverse name={done ? 'check' : 'error'} />
                                </div>
                            }
                        </Title>
                        <Text small mutted>{ description }</Text>
                    </Spacing>
                    { children }
                    {
                        invalid && errorMessage &&
                        <div {...css(styles.errorMessage)}>
                            <Text error>Mensagem de erro</Text>
                        </div>
                    }
                </div>
                { after }
            </div>
        )
    }
}

const ConfigurationItemWithStyles = withStyles(({ color, units, radius, font }) => ({
    configurationItem: {
        borderRadius: radius,
        borderWidth: 1,
        borderColor: color.blueGrayLight,
        borderStyle: 'solid',
        background: color.white,
        overflow: 'hidden'
    },

    configurationItem__content: {
        padding: units(1.5),
    },

    statusLabel: {
        width: 16,
        height: 16,
        marginLeft: 8,
        borderRadius: '50%',
        display: 'inline-flex',
        alignItems: 'center',
        justifyContent: 'center',

    },

    statusLabel_done: {
        background: color.success,
    },

    statusLabel_error: {
        background: color.alert
    },

    statusLabel__icon: {
        fill: color.white
    },

    errorMessage: {
        background: color.alertLight,
        marginTop: units(1.5),
        marginRight: units(-1.5),
        marginBottom: units(-1.5),
        marginLeft: units(-1.5),
        paddingTop: units(1),
        paddingRight: units(1.5),
        paddingBottom: units(1),
        paddingLeft: units(1.5),
    }
}))(ConfigurationItem);

ConfigurationItem.propTypes = propTypes;

export default ConfigurationItemWithStyles
