import React, { Fragment } from 'react'
import { withStyles } from '../helpers/withStyles'
import Blanket from './Blanket'
import Transition from 'react-transition-group/Transition'
import FlatButton from './FlatButton'

const Drawer = (
    {
        active,
        children,
        css,
        fullWidth,
        onClose,
        onClosed,
        right,
        width,
        styles
    }
) => {
    return (
        <Fragment>
            <Transition
                in={active}
                timeout={200}
                //mountOnEnter
                //unmountOnExit
                onEnter={node => node.scrollTop}
                onExited={() => onClosed && onClosed()}
            >
                {(state) => (
                    <div
                        {...css(
                            styles.drawer,
                            !fullWidth && styles.drawer_width_default,
                            fullWidth && styles.drawer_width_full,
                            right ? styles.drawer_right : styles.drawer_left,
                            (state === 'entering' || state === 'entered') && styles.entering,
                            (state === 'exiting' || state === 'exited') && styles.exiting,
                        )}
                    >
                        <div {...css(styles.closeButton)}>
                            <FlatButton transparent icon="error" onClick={() => onClose && onClose()} />
                        </div>
                        { children }
                    </div>
                )}
            </Transition>
            <Blanket onClick={() => onClose && onClose()} />
        </Fragment>
    )
}

const DrawerWithStyles = withStyles(({ color, units }) => ({
    drawer: {
        background: color.white,
        position: 'absolute',
        top: 0,
        bottom: 0,
        width: 0,
        overflow: 'hidden',
        zIndex: 99,
        transition: 'transform 200ms ease-out'
    },

    drawer_left: {
        left: 0,
        right: 'unset'
    },

    drawer_right: {
        right: 0,
        left: 'unset'
    },

    drawer_width_default: {
        width: units(24)
    },

    drawer_width_full: {
        width: '100%',
    },

    entering: {
        transform: 'translate(0, 0)',
        transition: 'transform 200ms ease-out'
    },

    exiting: {
        transform: 'translate(100%, 0)',
        transition: 'transform 200ms ease-out'
    },

    closeButton: {
        marginTop: units(.5),
        marginRight: units(.5),
        float: 'right'
    }
}))(Drawer)

export default DrawerWithStyles
