import React from 'react'
import PropTypes from 'prop-types'
import { withStyles } from '../helpers/withStyles'
import { withStylesPropTypes } from 'react-with-styles'
import Text from './Text'
import Spacing from './Spacing'

const propTypes = {
    ...withStylesPropTypes,
    children: PropTypes.any,
    actionLink: PropTypes.any,
    errorMessage: PropTypes.oneOfType([PropTypes.string, PropTypes.object]),
    hideLabel: PropTypes.bool,
    id: PropTypes.string,
    inline: PropTypes.bool,
    invalid: PropTypes.bool,
    inverse: PropTypes.bool,
    label: PropTypes.oneOfType([PropTypes.string, PropTypes.object]),
    labelDescription: PropTypes.string,
    large: PropTypes.bool,
    lightLabel: PropTypes.bool,
    small: PropTypes.bool
};

const FormElement = (
    {
        actionLink,
        children,
        css,
        errorMessage,
        hideLabel,
        id,
        inline,
        invalid,
        inverse,
        label,
        labelDescription,
        large,
        lightLabel,
        small,
        styles
    }
) => {
    return (
        <div {...css(styles.formElement, !inline && styles.block)}>
            <div {...css(styles.label, hideLabel && styles.label_hidden)}>
                {
                    typeof label === 'string'
                        ? <Text small bold={!lightLabel} light={lightLabel}>{ label }</Text>
                        : label
                }
                { labelDescription &&
                    <Spacing top={0.5}>
                        <Text small light>{ labelDescription }</Text>
                    </Spacing>
                }
            </div>
            { children }
            { invalid && errorMessage && <Text small error>{ errorMessage }</Text> }
        </div>
    )
};

FormElement.propTypes = propTypes;

const FormElementWithStyles = withStyles(({ units }) => ({
    formElement: {
        display: 'inline-block'
    },

    block: {
        display: 'block',
        width: '100%'
    },

    label: {
        marginBottom: units(0.5)
    },

    label_hidden: {
        border: 0,
        clip: 'rect(0, 0, 0, 0)',
        display: 'block',
        height: 1,
        margin: -1,
        overflow: 'hidden',
        padding: 0,
        position: 'absolute',
        width: 1
    }
}))(FormElement);

export default FormElementWithStyles
