import React from 'react'
import PropTypes from 'prop-types'
import { withStyles } from '../helpers/withStyles'
import { withStylesPropTypes } from 'react-with-styles'
import Spacing from './Spacing'
import Text from './Text'

const propTypes = {
    ...withStylesPropTypes,
    actionLink: PropTypes.any,
    children: PropTypes.any,
    collapseSpacing: PropTypes.bool,
    errorMessage: PropTypes.oneOfType([PropTypes.string, PropTypes.object]),
    hideLabel: PropTypes.bool,
    invalid: PropTypes.bool,
    label: PropTypes.oneOfType([PropTypes.string, PropTypes.object]),
    labelDescription: PropTypes.string,
    lightLabel: PropTypes.bool,
};

const FormElementGroup = (
    {
        actionLink,
        children,
        collapseSpacing,
        css,
        errorMessage,
        hideLabel,
        invalid,
        label,
        labelDescription,
        lightLabel,
        styles
    }
) => {
    return (
        <fieldset {...css(styles.formElementGroup)}>
            <legend {...css(styles.formElementGroup__legend)}>
                {
                    typeof label === 'string'
                        ? <Text small bold={!lightLabel} light={lightLabel}>{ label }</Text>
                        : label
                }
            </legend>
            { labelDescription &&
                <Spacing top={0.5}>
                    <Text small light>{ labelDescription }</Text>
                </Spacing>
            }
            <Spacing vertical={collapseSpacing ? 0 : 1}>
                { children }
            </Spacing>
            { invalid && errorMessage && <Text small error>{ errorMessage }</Text> }
        </fieldset>
    )
};

FormElementGroup.propTypes = propTypes;

const FormElementGroupWithStyles = withStyles(({ units }) => ({
    formElementGroup: {
        border: 0,
        margin: 0,
        padding: 0,
    },

    formElementGroup__legend: {
        padding: 0
    }
}))(FormElementGroup);

export default FormElementGroupWithStyles

