import React from 'react'
import PropTypes from 'prop-types'
import { withStyles } from '../helpers/withStyles'
import { withStylesPropTypes } from 'react-with-styles'

const propTypes = {
    ...withStylesPropTypes,
    children: PropTypes.any,
    right: PropTypes.bool,
    center: PropTypes.bool,
    fullHeight: PropTypes.bool,
    spaceBetween: PropTypes.bool,
    spaced: PropTypes.bool,
    top: PropTypes.bool,
    middle: PropTypes.bool,
    noWrap: PropTypes.bool,
    bottom: PropTypes.bool,
    stretch: PropTypes.bool,
    resetSpacing: PropTypes.bool,
    resetLargeSpacing: PropTypes.bool,
    resetMicroSpacing: PropTypes.bool,
    resetSmallSpacing: PropTypes.bool,
    vertical: PropTypes.bool
};

const Grid = (
    {
        children,
        right,
        center,
        fullHeight,
        spaceBetween,
        spaced,
        top,
        middle,
        noWrap,
        bottom,
        stretch,
        resetSpacing,
        resetLargeSpacing,
        resetMicroSpacing,
        resetSmallSpacing,
        styles,
        vertical,
        css
    }
) => {
    return (
        <div {...css(styles.container, fullHeight && styles.fullHeight)}>
            <div
                {...css(
                    styles.grid,
                    fullHeight && styles.fullHeight,
                    right && styles.grid_right,
                    center && styles.grid_center,
                    spaceBetween && styles.grid_spaceBetween,
                    spaced && styles.grid_spaced,
                    top && styles.grid_top,
                    middle && styles.grid_middle,
                    noWrap && styles.grid_noWrap,
                    bottom && styles.grid_bottom,
                    stretch && styles.grid_stretch,
                    resetSpacing && styles.grid_resetSpacing,
                    resetLargeSpacing && styles.grid_resetSpacing_large,
                    resetSmallSpacing && styles.grid_resetSpacing_small,
                    vertical && styles.grid_vertical
                )}
            >
                { children }
            </div>
        </div>
    )
};

Grid.propTypes = propTypes;

const GridWithStyles = withStyles(({ breakpoint, gutter }) => ({
    container: {
        display: 'flex',
        width: '100%',
        flex: 1
    },

    grid: {
        display: 'flex',
        width: '100%',
        alignItems: 'flex-start',
        flexWrap: 'wrap',
        flexDirection: 'row',
        flex: 1,
        boxSizing: 'border-box'
    },

    fullHeight: {
        height: '100%'
    },

    grid_vertical: {
        flexDirection: 'column',
        alignItems: 'stretch'
    },

    grid_noWrap: {
        flexWrap: 'nowrap'
    },

    grid_right: {
        alignItems: 'flex-end'
    },

    grid_center: {
        alignItems: 'center'
    },

    grid_spaceBetween: {
        alignItems: 'space-between'
    },

    grid_spaced: {
        alignItems: 'spaced'
    },

    grid_top: {
        justifyContent: 'flex-start'
    },

    grid_middle: {
        justifyContent: 'center'
    },

    grid_bottom: {
        justifyContent: 'flex-end'
    },

    grid_stretch: {
        justifyContent: 'stretch'
    },

    grid_resetSpacing: {
        marginLeft: - gutter.small.regular.left,
        marginRight: - gutter.small.regular.right,

        [breakpoint.mediumAndAbove]: {
            marginLeft: - gutter.medium.regular.left,
            marginRight: - gutter.medium.regular.right,
        },

        [breakpoint.large]: {
            marginLeft: - gutter.large.regular.left,
            marginRight: - gutter.large.regular.right,
        },

        [breakpoint.xlarge]: {
            marginLeft: - gutter.xlarge.regular.left,
            marginRight: - gutter.xlarge.regular.right,
        },
    },

    grid_resetSpacing_large: {
        marginLeft: - gutter.small.large.left,
        marginRight: - gutter.small.large.right,

        [breakpoint.mediumAndAbove]: {
            marginLeft: - gutter.medium.large.left,
            marginRight: - gutter.medium.large.right,
        },

        [breakpoint.large]: {
            marginLeft: - gutter.large.large.left,
            marginRight: - gutter.large.large.right,
        },

        [breakpoint.xlarge]: {
            marginLeft: - gutter.xlarge.large.left,
            marginRight: - gutter.xlarge.large.right,
        },
    },

    grid_resetSpacing_micro: {
        marginLeft: - gutter.small.micro.left,
        marginRight: - gutter.small.micro.right,

        [breakpoint.mediumAndAbove]: {
            marginLeft: - gutter.medium.micro.left,
            marginRight: - gutter.medium.micro.right,
        },

        [breakpoint.large]: {
            marginLeft: - gutter.large.micro.left,
            marginRight: - gutter.large.micro.right,
        },

        [breakpoint.xlarge]: {
            marginLeft: - gutter.xlarge.micro.left,
            marginRight: - gutter.xlarge.micro.right,
        },
    },

    grid_resetSpacing_small: {
        marginLeft: - gutter.small.small.left,
        marginRight: - gutter.small.small.right,

        [breakpoint.mediumAndAbove]: {
            marginLeft: - gutter.medium.small.left,
            marginRight: - gutter.medium.small.right,
        },

        [breakpoint.large]: {
            marginLeft: - gutter.large.small.left,
            marginRight: - gutter.large.small.right,
        },

        [breakpoint.xlarge]: {
            marginLeft: - gutter.xlarge.small.left,
            marginRight: - gutter.xlarge.small.right,
        },
    }
}))(Grid);

export default GridWithStyles
