import React from 'react'
import PropTypes from 'prop-types'
import Shimmer from './Shimmer'
import { withStyles } from '../helpers/withStyles'
import { withStylesPropTypes } from 'react-with-styles'

const propTypes = {
    ...withStylesPropTypes,
    inline: PropTypes.bool,
    loading: PropTypes.bool,
    aspectRatio: PropTypes.number,
    rectangular: PropTypes.bool,
    source: PropTypes.string,
    width: PropTypes.string
}

const defaultProps = {
    aspectRatio: 1,
    width: '100%'
}

const Image = ({ css, inline, loading, aspectRatio, rectangular, source, styles, width }) => {
    return (
        <div {...css(styles.container, inline && styles.inline, { width: width })}>
            <div
                {...css(
                    styles.image,
                    rectangular && styles.image_rectangular,
                    {
                        paddingTop: `${aspectRatio * 100}%`,
                        width: width,
                        backgroundImage: source && `url(${source})`
                    }
                )}
            />
            { loading && <div {...css(styles.loading)}><Shimmer width="100%" height="100%" /></div> }
        </div>
    )
}

Image.propTypes = propTypes
Image.defaultProps = defaultProps

const ImageWithStyles = withStyles(({ color, radius }) => ({
    container: {
        position: 'relative',
        overflow: 'hidden',
        boxSizing: 'border-box',
        borderRadius: radius,
    },

    image: {
        backgroundColor: color.gray,
        backgroundSize: 'cover',
        backgroundPosition: 'center'
    },

    inline: {
        display: 'inline-block'
    },

    image_rectangular: {
        borderRadius: 0
    },

    loading: {
        position: 'absolute',
        top: 0,
        right: 0,
        bottom: 0,
        left: 0
    }
}))(Image)

export default ImageWithStyles