import React from 'react'
import PropTypes from 'prop-types'
import FormElement from './FormElement'
import InputOnly from './InputOnly'

const propTypes = {
    actionLink: PropTypes.string,
    autoCapitalize: PropTypes.bool,
    autoComplete: PropTypes.oneOf(['off', 'on']),
    autoCorrect: PropTypes.any,
    autoFocus: PropTypes.bool,
    book: PropTypes.bool,
    borderless: PropTypes.bool,
    disabled: PropTypes.bool,
    errorMessage: PropTypes.any,
    focusBorderless: PropTypes.bool,
    hideLabel: PropTypes.bool,
    id: PropTypes.string,
    inline: PropTypes.bool,
    inputRef: PropTypes.func,
    invalid: PropTypes.bool,
    inverse: PropTypes.bool,
    label: PropTypes.string,
    labelDescription: PropTypes.string,
    large: PropTypes.bool,
    lightLabel: PropTypes.bool,
    mask: PropTypes.func,
    maxLength: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
    name: PropTypes.string.isRequired,
    onBlur: PropTypes.func,
    onChange: PropTypes.func,
    onClear: PropTypes.func,
    onFocus: PropTypes.func,
    onKeyDown: PropTypes.func,
    placeholder: PropTypes.string,
    prefix: PropTypes.object,
    prefixSeparator: PropTypes.bool,
    readOnly: PropTypes.bool,
    refForFocus: PropTypes.func,
    removeMargins: PropTypes.bool,
    removePrefixSpacing: PropTypes.bool,
    removeSuffixSpacing: PropTypes.bool,
    showFakeValuePlaceholder: PropTypes.bool,
    showOverflowEllipsis: PropTypes.bool,
    small: PropTypes.bool,
    spellCheck: PropTypes.any,
    suffix: PropTypes.object,
    suffixSeparator: PropTypes.bool,
    suffixText: PropTypes.any,
    type: PropTypes.string,
    underlineFocus: PropTypes.bool,
    value: PropTypes.string
};

const defaultProps = {
    autoComplete: 'off',
    type: 'text'
};

const Input = (
    {
        actionLink,
        autoCapitalize,
        autoComplete,
        autoCorrect,
        autoFocus,
        book,
        borderless,
        disabled,
        errorMessage,
        focusBorderless,
        hideLabel,
        id,
        inline,
        inputRef,
        invalid,
        inverse,
        label,
        labelDescription,
        large,
        lightLabel,
        mask,
        maxLength,
        name,
        onBlur,
        onChange,
        onClear,
        onFocus,
        onKeyDown,
        placeholder,
        prefix,
        prefixSeparator,
        readOnly,
        refForFocus,
        removeMargins,
        removePrefixSpacing,
        removeSuffixSpacing,
        showFakeValuePlaceholder,
        showOverflowEllipsis,
        small,
        spellCheck,
        suffix,
        suffixSeparator,
        suffixText,
        type,
        underlineFocus,
        value
    }
) => {
    return (
        <FormElement
            actionLink={actionLink}
            errorMessage={errorMessage}
            hideLabel={hideLabel}
            id={id}
            inline={inline}
            invalid={invalid}
            inverse={inverse}
            label={label}
            labelDescription={labelDescription}
            large={large}
            lightLabel={lightLabel}
            small={small}
        >
            <InputOnly
                autoCapitalize={autoCapitalize}
                autoComplete={autoComplete}
                autoCorrect={autoCorrect}
                autoFocus={autoFocus}
                book={book}
                borderless={borderless}
                disabled={disabled}
                focusBorderless={focusBorderless}
                id={id}
                inline={inline}
                inputRef={inputRef}
                invalid={invalid}
                inverse={inverse}
                large={large}
                mask={mask}
                maxLength={maxLength}
                name={name}
                onBlur={onBlur}
                onChange={onChange}
                onClear={onClear}
                onFocus={onFocus}
                onKeyDown={onKeyDown}
                placeholder={placeholder}
                prefix={prefix}
                prefixSeparator={prefixSeparator}
                readOnly={readOnly}
                refForFocus={refForFocus}
                removeMargins={removeMargins}
                removePrefixSpacing={removePrefixSpacing}
                removeSuffixSpacing={removeSuffixSpacing}
                showFakeValuePlaceholder={showFakeValuePlaceholder}
                showOverflowEllipsis={showOverflowEllipsis}
                small={small}
                spellCheck={spellCheck}
                suffix={suffix}
                suffixSeparator={suffixSeparator}
                suffixText={suffixText}
                type={type}
                underlineFocus={underlineFocus}
                value={value}
            />
        </FormElement>
    )
}

Input.propTypes = propTypes;
Input.defaultProps = defaultProps;

export default Input
