/*
state: focused ?
inputText: ''

*/

import React, { Fragment } from 'react'
import PropTypes from 'prop-types'
import MaskedTextInput from 'react-text-mask'
import Shimmer from './Shimmer'
import { withStylesPropTypes } from 'react-with-styles'
import { withStyles } from '../helpers/withStyles'

const propTypes = {
    ...withStylesPropTypes,
    actionLink: PropTypes.string,
    autoCapitalize: PropTypes.bool,
    autoComplete: PropTypes.oneOf(['off', 'on']),
    autoCorrect: PropTypes.any,
    autoFocus: PropTypes.bool,
    book: PropTypes.bool,
    borderless: PropTypes.bool,
    disabled: PropTypes.bool,
    flat: PropTypes.bool,
    floating: PropTypes.bool,
    focusBorderless: PropTypes.bool,
    id: PropTypes.string,
    inline: PropTypes.bool,
    inputRef: PropTypes.func,
    invalid: PropTypes.bool,
    inverse: PropTypes.bool,
    large: PropTypes.bool,
    mask: PropTypes.func,
    maxLength: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
    name: PropTypes.string.isRequired,
    onBlur: PropTypes.func,
    onChange: PropTypes.func,
    onClear: PropTypes.func,
    onFocus: PropTypes.func,
    onKeyDown: PropTypes.func,
    placeholder: PropTypes.string,
    prefix: PropTypes.object,
    prefixSeparator: PropTypes.bool,
    readOnly: PropTypes.bool,
    refForFocus: PropTypes.func,
    removeMargins: PropTypes.bool,
    removePrefixSpacing: PropTypes.bool,
    removeSuffixSpacing: PropTypes.bool,
    shimmer: PropTypes.bool,
    showFakeValuePlaceholder: PropTypes.bool,
    showOverflowEllipsis: PropTypes.bool,
    small: PropTypes.bool,
    spellCheck: PropTypes.any,
    suffix: PropTypes.object,
    suffixSeparator: PropTypes.bool,
    suffixText: PropTypes.any,
    type: PropTypes.string,
    underlineFocus: PropTypes.bool,
    value: PropTypes.string
};

const defaultProps = {
    autoComplete: 'off',
    type: 'text'
};

const InputOnly = (
    {
        actionLink,
        autoCapitalize,
        autoComplete,
        autoCorrect,
        autoFocus,
        book,
        borderless,
        css,
        disabled,
        flat,
        floating,
        focusBorderless,
        id,
        inline,
        inputRef,
        invalid,
        inverse,
        large,
        mask,
        maxLength,
        name,
        onBlur,
        onChange,
        onClear,
        onFocus,
        onKeyDown,
        placeholder,
        prefix,
        prefixSeparator,
        readOnly,
        refForFocus,
        removeMargins,
        removePrefixSpacing,
        removeSuffixSpacing,
        shimmer,
        showFakeValuePlaceholder,
        showOverflowEllipsis,
        small,
        spellCheck,
        styles,
        suffix,
        suffixSeparator,
        suffixText,
        type,
        underlineFocus,
        value
    }
) => {
    return (
        <div
            {...css(
                styles.inputOnly,
                !inline && styles.block,
                borderless && styles.borderless,
                disabled && styles.inputOnly_disabled,
                invalid && styles.inputOnly_invalid,
                flat && styles.inputOnly_flat,
                floating && styles.inputOnly_floating,
                focusBorderless && styles.inputOnly_focusBorderless,
                small && styles.inputOnly_small,
                removeMargins && styles.noMargin,
            )}
        >
            {
                shimmer && <div {...css(styles.shimmer)}><Shimmer width="100%" height="100%"/></div>
            }
            {
                prefix &&

                <Fragment>
                    <div {...css(styles.inputOnly__prefix, removePrefixSpacing && styles.noPadding)}>
                        { prefix }
                    </div>
                    { prefixSeparator && <div {...css(styles.separator, !removePrefixSpacing && styles.separator_prefix)} /> }
                </Fragment>
            }
            {
                mask != null ?

                    <MaskedTextInput
                        {...css(
                            styles.inputOnly__input,
                            showOverflowEllipsis && styles.inputOnly__input_ellipsis,
                            showFakeValuePlaceholder ? styles.inputOnly__input_fakeValuePlaceholder : styles.inputOnly__input_defaultPlaceholder,
                        )}
                        autoComplete={autoComplete}
                        autoCapitalize={autoCapitalize}
                        autoFocus={autoFocus}
                        autoCorrect={autoCorrect}
                        disabled={disabled}
                        id={id}
                        mask={mask}
                        maxLength={maxLength}
                        name={name}
                        onBlur={onBlur}
                        onChange={onChange}
                        onFocus={onFocus}
                        onKeyDown={onKeyDown}
                        placeholder={placeholder}
                        value={value}
                        readOnly={readOnly}
                        aria-readonly={readOnly}
                        spellCheck={spellCheck}
                        type={type}
                    />
                :
                    <input
                        {...css(
                            styles.inputOnly__input,
                            showOverflowEllipsis && styles.inputOnly__input_ellipsis,
                            showFakeValuePlaceholder ? styles.inputOnly__input_fakeValuePlaceholder : styles.inputOnly__input_defaultPlaceholder,
                        )}
                        autoComplete={autoComplete}
                        autoCapitalize={autoCapitalize}
                        autoFocus={autoFocus}
                        autoCorrect={autoCorrect}
                        disabled={disabled}
                        id={id}
                        maxLength={maxLength}
                        name={name}
                        onBlur={onBlur}
                        onChange={onChange}
                        onFocus={onFocus}
                        onKeyDown={onKeyDown}
                        placeholder={placeholder}
                        value={value}
                        readOnly={readOnly}
                        aria-readonly={readOnly}
                        spellCheck={spellCheck}
                        type={type}
                    />

            }
            {
                suffix &&

                <Fragment>
                    { suffixSeparator && <div {...css(styles.separator, !removeSuffixSpacing && styles.separator_suffix)} /> }
                    <div {...css(styles.inputOnly__suffix, removeSuffixSpacing && styles.noPadding)}>
                        { suffix }
                    </div>
                </Fragment>
            }
        </div>
    )
};

InputOnly.propTypes = propTypes;
InputOnly.defaultProps = defaultProps;

const InputOnlyWithStyles = withStyles(({ units, input, color, shadow }) => ({
    inputOnly: {
        ...input.default,
        display: 'inline-flex',
        position: 'relative',
        //zIndex: 0,
        flexWrap: 'nowrap',
        alignItems: 'center',
        boxSizing: 'border-box',
        height: units(2.5),

        ':focus-within': {
            ...input.focus
        }
    },

    inputOnly_focusBorderless: {
        ':focus-within': {
            borderWidth: 0,
        }
    },

    inputOnly_disabled: {
        ...input.disabled
    },

    inputOnly_invalid: {
        ...input.invalid
    },

    inputOnly_flat: {
        borderColor: color.blueGray,
        background: color.white
    },

    inputOnly_floating: {
        ...shadow.level1,
        background: color.white,
        borderColor: color.white
    },

    inputOnly_small: {
        ...input.small
    },

    noMargin: {
        marginTop: 0,
        marginRight: 0,
        marginBottom: 0,
        marginLeft: 0
    },

    noPadding: {
        paddingTop: 0,
        paddingRight: 0,
        paddingBottom: 0,
        paddingLeft: 0
    },

    inputOnly__input: {
        ...input.default,
        border: 0,
        margin: 0,
        background: color.transparent,
        width: '100%',
        height: 'auto',
        paddingTop: input.verticalPadding,
        paddingRight: input.horizontalPadding,
        paddingBottom: input.verticalPadding,
        paddingLeft: input.horizontalPadding,
        boxSizing: 'border-box',

        '::-ms-clear': {
            display: 'none'
        },

        ':focus': {
            outline: 'none',
            boxShadow: 'none',
            border: 0,
        },
    },

    inputOnly__input_ellipsis: {
        textOverflow: 'ellipsis'
    },

    inputOnly__input_defaultPlaceholder: {
        '::placeholder': {
            color: input.placeholderColor,
            opacity: 1
        }
    },

    inputOnly__input_fakeValuePlaceholder: {
        '::placeholder': {
            color: input.color,
            opacity: 1
        }
    },

    inputOnly__input_inversePlaceholder: {
        '::placeholder': {
            color: color.white,
            opacity: 1
        }
    },

    inputOnly__prefix: {
        paddingLeft: input.horizontalPadding,
        flexShrink: 0,
    },

    inputOnly__suffix: {
        paddingRight: input.horizontalPadding,
        flexShrink: 0,
    },

    separator: {
        width: 1,
        height: units(1.5),
        background: color.gray,
        flexShrink: 0
    },

    separator_prefix: {
        marginLeft: input.horizontalPadding,
    },

    separator_suffix: {
        marginRight: input.horizontalPadding,
    },

    block: {
        display: 'flex',
        width: '100%'
    },

    borderless: {
        borderColor: input.background
    },

    shimmer: {
        position: 'absolute',
        width: '100%',
        height: '100%',
        top: 0,
        right: 0,
        bottom: 0,
        left: 0
    }
}))(InputOnly);

export default InputOnlyWithStyles

