import React from 'react'
import PropTypes from 'prop-types'
import { withStyles } from '../helpers/withStyles'
import { withStylesPropTypes } from 'react-with-styles'

const propTypes = {
    ...withStylesPropTypes,
    children: PropTypes.any,
    htmlFor: PropTypes.string,
    inline: PropTypes.bool,
    table: PropTypes.bool
};

const Label = (
    {
        children,
        css,
        htmlFor,
        inline,
        styles,
        table
    }
) => {
    return (
        <label
            {...css(
                styles.label,
                inline && styles.label_inline,
                table && styles.label_table,
            )}
            htmlFor={htmlFor}
        >
            { table
                ? <div {...css(styles.label__tableRow)}>{ children }</div>
                : children
            }
        </label>
    )
};

Label.propTypes = propTypes;

const LabelWithStyles = withStyles(({ units, color }) => ({
    label: {
        backgroundColor: color.transparent,
        border: 0,
        cursor: 'pointer',
        display: 'block',
        padding: 0
    },

    label_inline: {
        display: 'inline-block',
        whiteSpace: 'nowrap',
    },

    label_table: {
        display: 'table'
    },

    label__tableRow: {
        display: 'table-row'
    }
}))(Label);

export default LabelWithStyles
