import React from 'react'
import PropTypes from 'prop-types'
import { css, withStyles } from '../helpers/withStyles'
import { withStylesPropTypes } from 'react-with-styles'

const propTypes = {
    ...withStylesPropTypes,
    isLoading: PropTypes.bool,
    small: PropTypes.bool,
    large: PropTypes.bool,
    primary: PropTypes.bool,
    secondary: PropTypes.bool,
    mono: PropTypes.bool
};

const Loader = ({ isLoading, styles, small, large, secondary, primary, mono }) => (
    <div {...css(styles.loader)}>
        <div {...css(
            styles.loader__ball,
            small && styles.loader__ball_small,
            large && styles.loader__ball_large,
            secondary && styles.loader__ball_secondary,
            primary && styles.loader__ball_primary,
            mono && styles.loader__ball_mono
        )} />
        <div {...css(
            styles.loader__ball,
            styles.loader__ball_second,
            small && styles.loader__ball_small,
            large && styles.loader__ball_large,
            secondary && styles.loader__ball_secondary,
            primary && styles.loader__ball_primary,
            mono && styles.loader__ball_mono
        )} />
        <div {...css(
            styles.loader__ball,
            styles.loader__ball_third,
            small && styles.loader__ball_small,
            large && styles.loader__ball_large,
            secondary && styles.loader__ball_secondary,
            primary && styles.loader__ball_primary,
            mono && styles.loader__ball_mono
        )} />
    </div>
);

Loader.propTypes = propTypes;

const bounceKeyframes = {
    '0%, 80%, 100%': {
        transform: 'scale(0)'
    },

    '40%': {
        transform: 'scale(1.0)'
    }

};

const LoaderWithStyles = withStyles(({ color, units }) => ({
    loader: {
        display: 'flex',
        alignItems: 'center',
        justifyContent: 'center'
    },

    loader__ball: {
        width: units(1),
        height: units(1),
        margin: units(.1),
        backgroundColor: color.white,
        borderRadius: '100%',
        display: 'inline-block',
        animationName: bounceKeyframes,
        animationDuration: '1.4s',
        animationIterationCount: 'infinite',
        animationEasing: 'ease-in-out',
        animationDirection: 'both'
    },

    loader__ball_small: {
        width: units(0.5),
        height: units(0.5)
    },

    loader__ball_large: {
        width: units(2),
        height: units(2)
    },

    loader__ball_primary: {
        backgroundColor: color.primary
    },

    loader__ball_secondary: {
        backgroundColor: color.secondary
    },

    loader__ball_mono: {
        backgroundColor: color.grayDarker
    },

    loader__ball_second: {
        animationDelay: '0.16s'
    },

    loader__ball_third: {
        animationDelay: '0.32s'
    }
}))(Loader);
export default LoaderWithStyles
