import React, {Component, Fragment} from 'react'
import PropTypes from 'prop-types'
import { withStyles } from '../helpers/withStyles'
import { withStylesPropTypes } from 'react-with-styles'
import Blanket from './Blanket'
import FlatButton from './FlatButton'

const propTypes = {
    ...withStylesPropTypes,
    children: PropTypes.any.isRequired,
    flex: PropTypes.bool,
    fullHeight: PropTypes.bool,
    fullScreen: PropTypes.bool,
    global: PropTypes.bool,
    large: PropTypes.bool,
    micro: PropTypes.bool,
    noPadding: PropTypes.bool,
    onClickBlanket: PropTypes.func,
    onClose: PropTypes.func,
    small: PropTypes.bool,
    visible: PropTypes.bool,
    xlarge: PropTypes.bool
};

class Modal extends Component {
    render() {
        const {
            css,
            children,
            flex,
            fullHeight,
            fullScreen,
            global,
            large,
            micro,
            noPadding,
            onClickBlanket,
            onClose,
            removeCloseButton,
            small,
            styles,
            visible,
            xlarge
        } = this.props;

        return (
            visible ?

            <Fragment>
                <div {...css(styles.container, fullScreen && styles.container_fullScreen)}>
                    <div
                        {...css(
                            styles.modal,
                            flex && styles.modal_flex,
                            fullHeight && styles.modal_fullHeight,
                            !fullScreen && !small && !large && !micro && styles.modal_default,
                            fullScreen && styles.modal_fullScreen,
                            large && styles.modal_large,
                            xlarge && styles.modal_xlarge,
                            noPadding && styles.noPadding,
                        )}
                    >
                        {
                            !removeCloseButton &&
                            <div {...css(styles.closeButton)}>
                                <FlatButton transparent icon="error" onClick={() => onClose && onClose()} />
                            </div>
                        }
                        { children }

                    </div>
                </div>
                <Blanket global={global} visible={true} onClick={() => onClickBlanket ? onClickBlanket() : onClose ? onClose() : null}/>
            </Fragment>

            : null
        )
    }
}

const ModalWithStyles = withStyles(({ breakpoint, color, units, radius, shadow }) => ({
    container: {
        position: 'absolute',
        top: 0,
        right: 0,
        bottom: 0,
        left: 0,
        height: '100vh',
        width: '100vw',
        overflow: 'auto',
        boxSizing: 'border-box',
    },

    container_fullScreen: {
        padding: 0,
        margin: 0,
        width: '100vw'
    },

    modal: {
        position: 'absolute',
        zIndex: 999,
        background: color.white,
        left: '50%',
        boxSizing: 'border-box',
        transform: 'translate(-50%, 0)',
        width: `calc(100% - ${units(2)}px)`,
        borderRadius: radius,
        borderColor: color.gray,
        borderWidth: 1,
        borderStyle: 'solid',
        padding: units(1.5),
        marginTop: units(1.5),
        ...shadow.level2
    },

    modal_default: {
        maxWidth: units(30)
    },

    modal_flex: {
        display: 'flex',
        flexDirection: 'column'
    },

    modal_large: {
        maxWidth: units(64)
    },

    modal_xlarge: {
        maxWidth: units(96)
    },

    modal_fullScreen: {
        width: 'unset',
        margin: 0,
        top: 0,
        right: 0,
        bottom: 0,
        left: 0,
        transform: 'unset',
        borderRadius: 0,
        border: 0
    },

    modal_fullHeight: {
        minHeight: `calc(100% - ${units(3)}px)`,
        [breakpoint.large]: {
            maxHeight: `calc(100% - ${units(3)}px)`,
        }
    },

    closeButton: {
        position: 'absolute',
        top: units(.5),
        right: units(.5),
    },

    noPadding: {
        padding: 0
    }
}))(Modal);

Modal.propTypes = propTypes;

export default ModalWithStyles
