import React from 'react'
import PropTypes from 'prop-types'
import Grid from './Grid'
import Cell from './Cell'
import Text from './Text'
import Title from './Title'
import Spacing from './Spacing'
import Visibility from './Visibility'
import { withStyles } from '../helpers/withStyles'
import { withStylesPropTypes } from 'react-with-styles'

const propTypes = {
    ...withStylesPropTypes,
    children: PropTypes.any,
    description: PropTypes.oneOfType([PropTypes.string, PropTypes.object]),
    inverse: PropTypes.bool,
    level: PropTypes.oneOf([1,2,3]),
    loading: PropTypes.bool,
    removeMargin: PropTypes.bool,
    section: PropTypes.string,
    title: PropTypes.string,
};

const defaultProps = {
    level: 1,
    title: ''
}

const PageHeader = (
    {
        children,
        css,
        description,
        inverse,
        level,
        loading,
        border,
        removeDescriptionSpacing,
        removeMargin,
        section,
        styles,
        title
    }
) => (
    <div
        {...css(
            styles.pageHeader,
            border && styles.pageHeader_withBorder,
            removeMargin && styles.pageHeader_noMargin
        )}
    >
        <Grid resetSpacing>
            <Cell size={12} autoOnMedium>
                { section && <Text muted small bold>{ section }</Text> }
                <Title title={title} level={level} noTopSpacing={section != null} noBottomSpacing={removeDescriptionSpacing} />
                {
                    description &&
                    typeof description === 'string'
                        ? <Text loading={loading}>{ description }</Text>
                        : description
                }
            </Cell>
            <Visibility showIf={children !== undefined}>
                <Cell size={12} shrinkOnMedium>
                    <Spacing top={0.5}>
                        { children }
                    </Spacing>
                </Cell>
            </Visibility>
        </Grid>
    </div>
);

PageHeader.propTypes = propTypes;
PageHeader.defaultProps = defaultProps;

const PageHeaderWithStyles = withStyles(({ color, units }) => ({
    pageHeader: {
        paddingTop: units(1),
        paddingBottom: units(1),
        display: 'flex',
        marginBottom: units(1.5)
    },

    pageHeader_withBorder: {
        borderBottomColor: color.blueGray,
        borderBottomWidth: 1,
        borderBottomStyle: 'solid',
        marginBottom: units(2)
    },

    pageHeader_noMargin: {
        marginBottom: 0
    }

}))(PageHeader);

export default PageHeaderWithStyles
