import React from 'react'
import PropTypes from 'prop-types'
import { withStyles } from '../helpers/withStyles'
import { withStylesPropTypes } from 'react-with-styles'

const propTypes = {
    ...withStylesPropTypes,
    checked: PropTypes.bool,
    disabled: PropTypes.bool,
    id: PropTypes.string,
    invalid: PropTypes.bool,
    name: PropTypes.string,
    onBlur: PropTypes.func,
    onChange: PropTypes.func,
    onFocus: PropTypes.func,
    refForFocus: PropTypes.func,
    value: PropTypes.oneOfType([PropTypes.string, PropTypes.object, PropTypes.number])
};

const RadioButtonOnly = (
    {
        checked,
        css,
        disabled,
        id,
        invalid,
        name,
        onBlur,
        onChange,
        onFocus,
        refForFocus,
        styles,
        value
    }
) => {
    return (
        <div {...css(styles.container)}>
            <div {...css(
                styles.radio,
                disabled && styles.radio_disabled,
                invalid && styles.radio_invalid,
            )}>
                <input
                    {...css(styles.radio__input)}
                    type="radio"
                    id={id}
                    name={name}
                    checked={checked}
                    disabled={disabled}
                    value={value}
                    aria-invalid={invalid}
                    onBlur={onBlur}
                    onChange={onChange}
                    onFocus={onFocus}
                />
                <div {...css(styles.radio__markContainer)} data-fake-radio={!invalid && !disabled}>
                    { checked && <div {...css(styles.radio__checkMark)} /> }
                </div>
            </div>
        </div>
    )
};

RadioButtonOnly.propTypes = propTypes;

const RadioButtonOnlyWithStyles = withStyles(({ units, color, input }) => ({
    container: {
        display: 'inline-block',
        position: 'relative',
        marginTop: 2,
        verticalAlign: 'top',
    },

    radio: {
        width: input.radio.size,
        height: input.radio.size,
        borderRadius: input.radio.borderRadius,
        background: input.radio.background,
        ...input.radio.border,
        boxSizing: 'border-box'
    },

    radio_disabled: {
        background: input.radio.disabled.background,
        ...input.radio.disabled.border
    },

    radio_invalid: {
        background: input.radio.invalid.background,
        ...input.radio.invalid.border
    },

    radio__input: {
        width: '100%',
        height: '100%',
        margin: 0,
        padding: 0,
        opacity: 0,
        position: 'absolute',

        ':focus + [data-fake-radio]': {
            zIndex: 1,
            borderWidth: 1,
            borderStyle: 'solid',
            borderColor: color.secondary,
            boxSizing: 'border-box'
        },
    },

    radio__markContainer: {
        display: 'flex',
        position: 'absolute',
        width: '100%',
        height: '100%',
        left: 0,
        top: 0,
        alignItems: 'center',
        justifyContent: 'center',
        borderRadius: input.radio.border.borderRadius,
    },

    radio__checkMark: {
        ...input.radio.checkMark,

    }
}))(RadioButtonOnly);

export default RadioButtonOnlyWithStyles
