import React, { Fragment } from 'react'
import PropTypes from 'prop-types'
import ReactSelect from 'react-select'
import CreatableSelect from 'react-select/lib/Creatable'
import Shimmer from './Shimmer'
import { withStylesPropTypes } from 'react-with-styles'
import { withStyles } from '../helpers/withStyles'
import Theme from '../themes/CinnectaTheme'

const propTypes = {
    ...withStylesPropTypes,
    actionLink: PropTypes.string,
    autoCapitalize: PropTypes.bool,
    autoComplete: PropTypes.oneOf(['off', 'on']),
    autoCorrect: PropTypes.any,
    autoFocus: PropTypes.bool,
    book: PropTypes.bool,
    borderless: PropTypes.bool,
    clearable: PropTypes.bool,
    closeMenuOnSelect: PropTypes.bool,
    defaultValue: PropTypes.object,
    disabled: PropTypes.bool,
    flat: PropTypes.bool,
    floating: PropTypes.bool,
    focusBorderless: PropTypes.bool,
    id: PropTypes.string,
    inline: PropTypes.bool,
    inputRef: PropTypes.func,
    insidePrefix: PropTypes.bool,
    insideSuffix: PropTypes.bool,
    invalid: PropTypes.bool,
    inverse: PropTypes.bool,
    loading: PropTypes.bool,
    large: PropTypes.bool,
    loadingMessage: PropTypes.string,
    mask: PropTypes.func,
    maxLength: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
    multiple: PropTypes.bool,
    name: PropTypes.string.isRequired,
    noOptionsMessage: PropTypes.string,
    onBlur: PropTypes.func,
    onChange: PropTypes.func,
    onClear: PropTypes.func,
    onCreateOption: PropTypes.func,
    onFocus: PropTypes.func,
    onKeyDown: PropTypes.func,
    placeholder: PropTypes.string,
    prefix: PropTypes.object,
    prefixSeparator: PropTypes.bool,
    readOnly: PropTypes.bool,
    refForFocus: PropTypes.func,
    removeMargins: PropTypes.bool,
    removePrefixSpacing: PropTypes.bool,
    removeSuffixSpacing: PropTypes.bool,
    right: PropTypes.bool,
    shimmer: PropTypes.bool,
    showFakeValuePlaceholder: PropTypes.bool,
    showOverflowEllipsis: PropTypes.bool,
    small: PropTypes.bool,
    spellCheck: PropTypes.any,
    suffix: PropTypes.object,
    suffixSeparator: PropTypes.bool,
    suffixText: PropTypes.any,
    type: PropTypes.string,
    underlineFocus: PropTypes.bool,
    value: PropTypes.oneOfType([PropTypes.string, PropTypes.array])
};

const defaultProps = {
    options: [],
    placeholder: 'Selecione...',
    clearable: false,
    closeMenuOnSelect: true,
    noOptionsMessage: 'Sem opções...'
};

const selectStyles = {
    option: (base, state) => ({
        //...base,
        appearance: 'none',
        borderWidth: 0,
        height: Theme.units(2),
        paddingTop: Theme.units(0.25),
        paddingRight: Theme.units(0.75),
        paddingBottom: Theme.units(0.25),
        paddingLeft: Theme.units(0.75),
        borderRadius: Theme.radius,
        fontSize: Theme.units(0.95),
        display: 'flex',
        alignItems: 'center',
        outline: 0,
        position: 'relative',
        margin: 0,
        fontWeight: 500,
        fontFamily: Theme.font.default,
        cursor: 'pointer',
        boxSizing: 'border-box',
        background: state.isSelected ? Theme.color.blueGrayDark : state.isFocused ? Theme.color.grayLight : Theme.color.white,
        color: state.isSelected ? Theme.color.white : Theme.color.primary,
        whiteSpace: 'nowrap',

        '&:hover': {
            background: !state.isSelected && Theme.color.blueGrayLight
        },

        '&:active': {
            background: !state.isSelected && Theme.color.blueGray
        }
    }),

    menu: (base, state) => ({
        //...base,
        position: 'absolute',
        marginTop: Theme.units(.25),
        top: '100%',
        backgroundColor: Theme.color.white,
        boxShadow: `0 ${Theme.units(0.5)} ${Theme.units(0.75)} ${Theme.units(-0.45)} ${Theme.color.shadow}`,
        padding: Theme.units(0.5),
        borderRadius: Theme.radius,
        borderWidth: 1,
        borderStyle: 'solid',
        borderColor: Theme.color.blueGrayLight,
        zIndex: 2,
        minWidth: '100%',
        boxSizing: 'border-box'
        //transform: 'translate(0, -10%)',
        //transition: 'opacity 200ms ease-out, transform 300ms ease-out'
    }),

    menuList: (base) => ({
        ...base,
        padding: 0
    }),

    control: (base) => ({
        //...base,
        width: '100%',
        display: 'flex',
        alignItems: 'center',
        flex: 1,
        flexWrap: 'wrap',
        position: 'relative',
        boxSizing: 'border-box'
    }),

    container: () => ({
        width: '100%'
    }),

    indicatorSeparator: () => ({
        display: 'none'
    }),

    dropdownIndicator: (base, state) => ({
        ...base,
        fill: Theme.color.grayDark,
        color: state.isFocused ? Theme.color.grayDarker : Theme.color.grayDark,
        opacity: 1,
        width: 32,

        '&:hover': {
            color: Theme.color.grayDarker,
        }
    }),

    singleValue: (base, state) => ({
        ...base,
        transition: 'opacity 300ms',
        color: Theme.color.grayDarker,
        position: 'static',
        transform: 'none',
        maxWidth: '100%',
        order: 2
    }),

    input: (base) => ({
        ...base,
        color: Theme.color.grayDarker,
        margin: 0,
        padding: 0,
        order: 1
    }),

    placeholder: (base) => ({
        ...base,
        color: Theme.input.placeholderColor,
        position: 'static',
        transform: 'none',
        order: 2
    }),

    multiValue: (base) => ({
        ...base,
        background: Theme.color.gray,
        color: Theme.color.grayDarker,
    }),

    multiValueRemove: (base) => ({
        ...base,
        borderRadius: '50%',
        height: 18,
        width: 18,
        padding: 0,
        marginTop: 2,
        marginLeft: 4,
        marginRight: 2,
        display: 'flex',
        alignItems: 'center',
        justifyContent: 'center',
        color: Theme.color.grayDarker,
        fill: Theme.color.grayDarker,

        '&:hover': {
            background: Theme.color.shadowWeak,
            color: Theme.color.grayDarker,
            fill: Theme.color.grayDarker,
        }
    }),

    multiValueLabel: (base) => ({
        ...base,
        color: Theme.color.grayDarker
    })
}

const SelectOnly = (
    {
        autocomplete,
        autoFocus,
        book,
        borderless,
        clearable,
        css,
        closeMenuOnSelect,
        defaultValue,
        disabled,
        flat,
        floating,
        focusBorderless,
        id,
        inline,
        inputRef,
        insidePrefix,
        insideSuffix,
        invalid,
        inverse,
        large,
        loading,
        multiple,
        name,
        noOptionsMessage,
        onBlur,
        onChange,
        onClear,
        onCreateOption,
        onFocus,
        onKeyDown,
        options,
        placeholder,
        prefix,
        prefixSeparator,
        readOnly,
        refForFocus,
        removeMargins,
        removePrefixSpacing,
        removeSuffixSpacing,
        shimmer,
        showFakeValuePlaceholder,
        showOverflowEllipsis,
        small,
        spellCheck,
        styles,
        suffix,
        suffixSeparator,
        suffixText,
        underlineFocus,
        value
    }
) => {
    return (
        <div
            {...css(
                styles.selectOnly,
                !inline && styles.block,
                borderless && styles.borderless,
                disabled && styles.selectOnly_disabled,
                invalid && styles.selectOnly_invalid,
                flat && styles.selectOnly_flat,
                floating && styles.selectOnly_floating,
                focusBorderless && styles.selectOnly_focusBorderless,
                loading && styles.selectOnly_disabled,
                small && styles.selectOnly_small,
                removeMargins && styles.noMargin,
                insidePrefix && styles.selectOnly_insidePrefix,
                insideSuffix && styles.selectOnly_insideSuffix,
            )}
        >
            {
                shimmer && <div {...css(styles.shimmer)}><Shimmer width="100%" height="100%"/></div>
            }
            {
                prefix &&

                <Fragment>
                    <div {...css(styles.selectOnly__prefix, removePrefixSpacing && styles.noPadding)}>
                        { prefix }
                    </div>
                    { prefixSeparator && <div {...css(styles.separator, styles.separator_prefix, removePrefixSpacing && styles.noMargin)} /> }
                </Fragment>
            }
            {
                onCreateOption ?
                    <CreatableSelect
                        closeMenuOnSelect={closeMenuOnSelect}
                        formatCreateLabel={value => `Criar "${value}"`}
                        defaultValue={defaultValue}
                        isDisabled={disabled || loading}
                        isLoading={loading}
                        isClearable={clearable}
                        isMulti={multiple}
                        isSearchable={autocomplete}

                        isValidNewOption={(inputValue, selectValue, selectOptions) => {
                            const isNotDuplicated = !selectOptions
                                .map(option => option.label)
                                .includes(inputValue);
                            const isNotEmpty = inputValue !== '';
                            return isNotEmpty && isNotDuplicated;
                        }}
                        name={name}
                        noOptionsMessage={() => noOptionsMessage}
                        onBlur={onBlur}
                        onChange={onChange}
                        onCreateOption={onCreateOption}
                        onFocus={onFocus}
                        onKeyDown={onKeyDown}
                        options={options}
                        placeholder={placeholder}
                        styles={selectStyles}
                        theme={(theme) => ({
                            ...theme,
                            width: '100%',
                            borderRadius: 0,
                            colors: {
                                ...theme.colors,
                                text: 'orangered',
                                primary25: Theme.color.blueGray,
                                primary: Theme.color.primary,
                            }
                        })}
                        value={value}
                    />
                :

                    <ReactSelect
                        closeMenuOnSelect={closeMenuOnSelect}
                        defaultValue={defaultValue}
                        isDisabled={disabled}
                        isLoading={loading}
                        isClearable={clearable}
                        isMulti={multiple}
                        isSearchable={autocomplete}
                        name={name}
                        noOptionsMessage={() => noOptionsMessage}
                        onBlur={onBlur}
                        onChange={onChange}
                        onFocus={onFocus}
                        onKeyDown={onKeyDown}
                        options={options}
                        placeholder={placeholder}
                        styles={selectStyles}
                        theme={(theme) => ({
                            ...theme,
                            width: '100%',
                            borderRadius: 0,
                            colors: {
                                ...theme.colors,
                                text: 'orangered',
                                primary25: Theme.color.blueGray,
                                primary: Theme.color.primary,
                            }
                        })}
                        value={value}
                    />
            }
            {/*
            <input
                {...css(
                    styles.selectOnly__input,
                    showOverflowEllipsis && styles.selectOnly__input_ellipsis,
                    showFakeValuePlaceholder ? styles.selectOnly__input_fakeValuePlaceholder : styles.selectOnly__input_defaultPlaceholder,
                )}
                autoComplete={autoComplete}
                autoCapitalize={autoCapitalize}
                autoFocus={autoFocus}
                autoCorrect={autoCorrect}
                disabled={disabled}
                id={id}
                maxLength={maxLength}
                name={name}

                placeholder={placeholder}
                value={value}
                readOnly={readOnly}
                aria-readonly={readOnly}
                spellCheck={spellCheck}
                type={type}
            />
            */}
            {
                suffix &&

                <Fragment>
                    { suffixSeparator && <div {...css(styles.separator, styles.separator_suffix, removeSuffixSpacing && styles.noMargin)} /> }
                    <div {...css(styles.selectOnly__suffix, removeSuffixSpacing && styles.noPadding)}>
                        { suffix }
                    </div>
                </Fragment>
            }
        </div>
    )
};

SelectOnly.propTypes = propTypes;
SelectOnly.defaultProps = defaultProps;

const SelectOnlyWithStyles = withStyles(({ input, color, shadow }) => ({
    selectOnly: {
        ...input.default,
        display: 'inline-flex',
        position: 'relative',
        flexWrap: 'nowrap',
        alignItems: 'center',
        boxSizing: 'border-box',
        minHeight: 40,

        ':focus-within': {
            ...input.focus
        }
    },

    selectOnly_focusBorderless: {
        ':focus-within': {
            borderWidth: 0,
        }
    },

    selectOnly_insidePrefix: {
        height: 38,
    },

    selectOnly_insideSuffix: {
        height: 38,
    },

    selectOnly_disabled: {
        ...input.disabled
    },

    selectOnly_invalid: {
        ...input.invalid
    },

    selectOnly_flat: {
        borderColor: color.blueGray,
        background: color.white
    },

    selectOnly_floating: {
        ...shadow.level1,
        background: color.white,
        borderColor: color.white
    },

    selectOnly_small: {
        ...input.small
    },

    noMargin: {
        marginTop: 0,
        marginRight: 0,
        marginBottom: 0,
        marginLeft: 0
    },

    noPadding: {
        paddingTop: 0,
        paddingRight: 0,
        paddingBottom: 0,
        paddingLeft: 0
    },

    selectOnly__input: {
        ...input.default,
        border: 0,
        margin: 0,
        background: color.transparent,
        width: '100%',
        height: 'auto',
        paddingTop: input.verticalPadding,
        paddingRight: input.horizontalPadding,
        paddingBottom: input.verticalPadding,
        paddingLeft: input.horizontalPadding,
        boxSizing: 'border-box',

        '::-ms-clear': {
            display: 'none'
        },

        ':focus': {
            outline: 'none',
            boxShadow: 'none',
            border: 0,
        },
    },

    selectOnly__input_ellipsis: {
        textOverflow: 'ellipsis'
    },

    selectOnly__input_defaultPlaceholder: {
        '::placeholder': {
            color: input.placeholderColor,
            opacity: 1
        }
    },

    selectOnly__input_fakeValuePlaceholder: {
        '::placeholder': {
            color: input.color,
            opacity: 1
        }
    },

    selectOnly__input_inversePlaceholder: {
        '::placeholder': {
            color: color.white,
            opacity: 1
        }
    },

    selectOnly__prefix: {
        paddingLeft: input.horizontalPadding,
        flexShrink: 0,
    },

    selectOnly__suffix: {
        paddingRight: input.horizontalPadding,
        flexShrink: 0,
    },

    separator: {
        width: 1,
        height: 24,
        background: color.gray,
        flexShrink: 0
    },

    separator_prefix: {
        marginLeft: input.horizontalPadding,
    },

    separator_suffix: {
        marginRight: input.horizontalPadding,
    },

    block: {
        display: 'flex',
        width: '100%'
    },

    borderless: {
        borderColor: input.background
    },

    shimmer: {
        position: 'absolute',
        width: '100%',
        height: '100%',
        top: 0,
        right: 0,
        bottom: 0,
        left: 0
    }
}))(SelectOnly);

export default SelectOnlyWithStyles

