import React from 'react'
import { withStyles } from '../helpers/withStyles'

const Separator = ({ children, css, largeSpacing, noSpacing, smallSpacing, styles, vertical }) => {
    return (
        <div
            {...css(
                styles.separator,
                vertical ? styles.separator_vertical : styles.separator_horizontal,
                !vertical && smallSpacing && styles.separator_horizontal_smallSpacing,
                noSpacing && styles.separator_noSpacing,
            )}
        >
            <div {...css(styles.separator__line)} />
            { children && <div {...css(styles.separator__content)}>{ children }</div> }
            <div {...css(styles.separator__line)} />
        </div>
    )
};

const SeparatorWithStyles = withStyles(({ color, units }) => ({
    separator: {
        display: 'flex',
        alignItems: 'center',
        color: color.grayDark
    },

    separator_horizontal: {
        flexDirection: 'row',
        width: '100%',
        marginTop: units(2),
        marginBottom: units(2)
    },

    separator_noSpacing: {
        marginTop: 0,
        marginRight: 0,
        marginBottom: 0,
        marginLeft: 0,
    },

    separator_horizontal_smallSpacing: {
        marginTop: units(1),
        marginBottom: units(1)
    },

    separator_horizontal_largeSpacing: {
        marginTop: units(3),
        marginBottom: units(3)
    },

    separator__line: {
        flex: 1,
        borderBottomWidth: 1,
        borderBottomStyle: 'solid',
        borderBottomColor: color.gray
    },

    separator__content: {
        paddingLeft: units(1),
        paddingRight: units(1)
    }
}))(Separator);

export default SeparatorWithStyles
