import React from 'react'
import PropTypes from 'prop-types'
import { css, withStyles } from '../helpers/withStyles'
import { withStylesPropTypes } from 'react-with-styles'

const propTypes = {
    ...withStylesPropTypes,
    height: PropTypes.string,
    width: PropTypes.string,
    block: PropTypes.bool,
};

const Shimmer = ({ height, width, block, styles }) => (
    <span
        {...css(
            styles.shimmer,
            block && styles.shimmer_block
        )}
        aria-busy="true"
        style={{ height, width }}
    />
);

Shimmer.propTypes = propTypes;

const ShimmerWithStyles = withStyles(({ color, animation }) => ({
    shimmer: {
        backgroundColor: color.shimmer.from,
        display: 'inline-block',
        position: 'relative',
        animationDirection: 'alternate',
        animationDuration: '1s',
        animationFillMode: 'forwards',
        animationIterationCount: 'infinite',
        animationName: animation.shimmer,
        animationTimingFunction: 'ease-in-out'
    },

    shimmer_block: {
        display: 'block'
    }
}))(Shimmer);

export default ShimmerWithStyles



