import React, { Component } from 'react'
import PropTypes from 'prop-types'
import { css } from '../helpers/withStyles'
import theme from '../themes/CinnectaTheme'
import { withBreakpoints } from './Responsive'

const propTypes = {
    bottom: PropTypes.number,
    bottomLargeAndAbove: PropTypes.number,
    bottomMediumAndAbove: PropTypes.number,
    children: PropTypes.any,
    horizontal: PropTypes.number,
    horizontalLargeAndAbove: PropTypes.number,
    horizontalMediumAndAbove: PropTypes.number,
    inline: PropTypes.bool,
    inside: PropTypes.bool,
    left: PropTypes.number,
    leftLargeAndAbove: PropTypes.number,
    leftMediumAndAbove: PropTypes.number,
    right: PropTypes.number,
    rightLargeAndAbove: PropTypes.number,
    rightMediumAndAbove: PropTypes.number,
    top: PropTypes.number,
    topLargeAndAbove: PropTypes.number,
    topMediumAndAbove: PropTypes.number,
    vertical: PropTypes.number,
    verticalLargeAndAbove: PropTypes.number,
    verticalMediumAndAbove: PropTypes.number,
    isGreaterThan: PropTypes.func,
};

class Spacing extends Component {
    render() {
        const {
            bottom,
            bottomLargeAndAbove,
            bottomMediumAndAbove,
            children,
            horizontal,
            horizontalLargeAndAbove,
            horizontalMediumAndAbove,
            inline,
            inside,
            left,
            leftLargeAndAbove,
            leftMediumAndAbove,
            right,
            rightLargeAndAbove,
            rightMediumAndAbove,
            top,
            topLargeAndAbove,
            topMediumAndAbove,
            vertical,
            verticalLargeAndAbove,
            verticalMediumAndAbove,
            isGreaterThan
        } = this.props;

        const getTopMargin = () => {
            if((topLargeAndAbove != null || verticalLargeAndAbove != null) && isGreaterThan('large')) {
                return topLargeAndAbove || verticalLargeAndAbove
            } else if((topMediumAndAbove != null || verticalMediumAndAbove != null) && isGreaterThan('medium')) {
                return topMediumAndAbove || verticalMediumAndAbove
            } else {
                return top || vertical
            }
        };

        const getRightMargin = () => {
            if((rightLargeAndAbove != null || horizontalLargeAndAbove != null) && isGreaterThan('large')) {
                return rightLargeAndAbove || horizontalLargeAndAbove
            } else if((rightMediumAndAbove != null || horizontalMediumAndAbove != null) && isGreaterThan('medium')) {
                return rightMediumAndAbove || horizontalMediumAndAbove
            } else {
                return right || horizontal
            }
        };

        const getBottomMargin = () => {
            if((bottomLargeAndAbove != null || verticalLargeAndAbove != null) && isGreaterThan('large')) {
                return bottomLargeAndAbove || verticalLargeAndAbove
            } else if((bottomMediumAndAbove != null || verticalMediumAndAbove != null) && isGreaterThan('medium')) {
                return bottomMediumAndAbove || verticalMediumAndAbove
            } else {
                return bottom || vertical
            }
        };

        const getLeftMargin = () => {
            if((leftLargeAndAbove != null || horizontalLargeAndAbove != null) && isGreaterThan('large')) {
                return leftLargeAndAbove || horizontalLargeAndAbove
            } else if((leftMediumAndAbove != null || horizontalMediumAndAbove != null) && isGreaterThan('medium')) {
                return leftMediumAndAbove || horizontalMediumAndAbove
            } else {
                return left || horizontal
            }
        };

        const topMargin = getTopMargin();
        const rightMargin = getRightMargin();
        const bottomMargin = getBottomMargin();
        const leftMargin = getLeftMargin();

        return (
            inline ?
                <span {...css({
                    [inside ? 'paddingTop' : 'marginTop']: topMargin ? topMargin * theme.unit : null,
                    [inside ? 'paddingRight' : 'marginRight']: rightMargin ? rightMargin * theme.unit : null,
                    [inside ? 'paddingBottom' : 'marginBottom']: bottomMargin ? bottomMargin * theme.unit : null,
                    [inside ? 'paddingLeft' : 'marginLeft']: leftMargin ? leftMargin * theme.unit : null,
                    display: 'inline-block'
                })}>
                    {children}
                </span>
            :
                <div {...css({
                    [inside ? 'paddingTop' : 'marginTop']: topMargin ? topMargin * theme.unit : null,
                    [inside ? 'paddingRight' : 'marginRight']: rightMargin ? rightMargin * theme.unit : null,
                    [inside ? 'paddingBottom' : 'marginBottom']: bottomMargin ? bottomMargin * theme.unit : null,
                    [inside ? 'paddingLeft' : 'marginLeft']: leftMargin ? leftMargin * theme.unit : null,
                })}>
                    {children}
                </div>
        )
    }
}

Spacing.propTypes = propTypes;

const SpacingWithBreakpoints = withBreakpoints(Spacing);
export default SpacingWithBreakpoints
