import React from 'react'
import PropTypes from 'prop-types'
import { withStyles } from '../helpers/withStyles'
import { withStylesPropTypes } from 'react-with-styles'

const propTypes = {
    ...withStylesPropTypes,
    micro: PropTypes.bool,
    small: PropTypes.bool,
    large: PropTypes.bool,
    primary: PropTypes.bool,
    secondary: PropTypes.bool,
    fast: PropTypes.bool,
    slow: PropTypes.bool,
}

const Spinner = ({ micro, small, large, primary, secondary, fast, slow, css, styles }) => (
    <div
        {...css(
            styles.spinner,
            micro && styles.spinner_micro,
            small && styles.spinner_small,
            large && styles.spinner_large,
            primary && styles.spinner_primary,
            secondary && styles.spinner_secondary,
            fast && styles.spinner_fast,
            slow && styles.spinner_slow,
        )}
    />
);

Spinner.propTypes = propTypes;

const SpinnerWithStyles = withStyles(({ color, units, animation }) => ({
    spinner: {
        borderWidth: units(.2),
        borderStyle: 'solid',
        borderTopColor: color.white,
        borderRightColor: color.transparent,
        borderBottomColor: color.transparent,
        borderLeftColor: color.transparent,
        borderRadius: '50%',
        animationName: animation.spinner,
        animationDuration: '.6s',
        animationIterationCount: 'infinite',
        animationEasing: 'linear',
        width: units(2.5),
        height: units(2.5),
    },

    spinner_micro: {
        width: units(1),
        height: units(1),
        borderWidth: units(0.125)
    },

    spinner_small: {
        width: units(1.375),
        height: units(1.375),
        borderWidth: units(0.125)
    },

    spinner_large: {
        width: units(5),
        height: units(5),
    },

    spinner_primary: {
        borderTopColor: color.primary
    },

    spinner_secondary: {
        borderTopColor: color.secondary
    },

    spinner_fast: {
        animationDuration: '.3s'
    },

    spinner_slow: {
        animationDuration: '1s'
    },
}))(Spinner);

export default SpinnerWithStyles
