import React from 'react'
import PropTypes from 'prop-types'
import { withStyles } from '../helpers/withStyles'
import Text from './Text'
import Shimmer from './Shimmer'

const propTypes = {
    color: PropTypes.string,
    loading: PropTypes.bool,
    text: PropTypes.string,
};

const StatusIndicator = ({ text, color, css, loading, styles }) => (
    <span {...css(styles.label)}>
        <div
            {...css(
                styles.label__color,
                { backgroundColor: color }
            )}
        >
            { loading && <div {...css(styles.label__color__shimmer)}><Shimmer width="100%" height="100%"/></div> }
        </div>
        <Text small shimmerWidth="3rem" loading={loading}>{ text }</Text>
    </span>
);

StatusIndicator.propTypes = propTypes;

const StatusIndicatorWithStyles = withStyles(({ color, animation, units }) => ({
    label: {
        display: 'flex',
        alignItems: 'center',
        flexShrink: 0,
    },

    label__color: {
        //backgroundColor: color.blueGrayDark,
        width: units(.625),
        height: units(.625),
        borderRadius: '50%',
        marginRight: units(0.5),
        flexShrink: 0,
        position: 'relative',
        overflow: 'hidden',
    },

    label__color__shimmer: {
        display: 'flex',
        position: 'absolute',
        width: '100%',
        height: '100%',
        top: 0,
        right: 0,
        bottom: 0,
        left: 0
    }
}))(StatusIndicator);

export default StatusIndicatorWithStyles
