import React from 'react'
import PropTypes from 'prop-types'
import Loader from './Loader'
import Shimmer from './Shimmer'
import { withStyles } from '../helpers/withStyles'
import { withStylesPropTypes } from 'react-with-styles'

const propTypes = {
    ...withStylesPropTypes,
    active: PropTypes.bool,
    disabled: PropTypes.bool,
    loading: PropTypes.bool,
    fullWidth: PropTypes.bool,
    block: PropTypes.bool,
    compact: PropTypes.bool,
    inverse: PropTypes.bool,
    mono: PropTypes.bool,
    noSpacing: PropTypes.bool,
    soft: PropTypes.bool,
    primary: PropTypes.bool,
    rectangular: PropTypes.bool,
    secondary: PropTypes.bool,
    shade: PropTypes.bool,
    shimmer: PropTypes.bool,
    short: PropTypes.bool,
    transparent: PropTypes.bool,
    type: PropTypes.string,
    underlined: PropTypes.bool,
    noBorder: PropTypes.bool,
    children: PropTypes.node
};

const defaultProps = {
    type: 'button'
}

const TabButton = (
    {
        styles,
        active,
        children,
        disabled,
        loading,
        fullWidth,
        block,
        compact,
        inverse,
        grouped,
        groupedFirst,
        groupedLast,
        mono,
        noSpacing,
        shade,
        soft,
        primary,
        rectangular,
        secondary,
        shimmer,
        short,
        transparent,
        type,
        underlined,
        noBorder,

        theme,
        css,

        href,
        large,
        noWrap,
        shadowLevel,
        small,
        ...props
    }
) => {
    return (
        <button
            {...props}
            {...css(
                styles.button,
                active      && styles.button_active,
                loading     && styles.button_loading,
                fullWidth   && styles.button_fullWidth,
                block       && styles.button_block,
                compact     && styles.button_compact,
                disabled    && styles.button_disabled,
                inverse     && styles.button_inverse,
                grouped     && styles.button_grouped,
                groupedFirst && styles.button_groupedFirst,
                groupedLast && styles.button_groupedLast,
                mono        && styles.button_mono,
                noSpacing   && styles.button_noSpacing,
                soft        && styles.button_soft,
                primary     && styles.button_primary,
                rectangular && styles.button_rectangular,
                secondary   && styles.button_secondary,
                shade       && styles.button_shade,
                short       && styles.button_short,
                transparent && styles.button_transparent,
                underlined  && styles.button_underlined,
                noBorder    && styles.button_noBorder,
            )}
            disabled={disabled || loading}
            type={type}
        >
            {
                loading && shimmer &&

                <div{...css(styles.shimmer)}>
                    <Shimmer height="100%" width="100%" />
                </div>
            }
            <div
                {...css(
                    styles.button__content,
                    loading && styles.button__content_loading,
                    fullWidth && styles.button__content_fullWidth,
                )}
            >
                { children }
            </div>
            { loading &&
            <div {...css(styles.button__loader, shimmer && styles.button__loader_shimmer)}>
                { !shimmer && <Loader small primary={inverse && soft} secondary={secondary} mono={mono} /> }
            </div>
            }
        </button>
    )
};

TabButton.propTypes = propTypes;
TabButton.defaultProps = defaultProps;

const TabButtonWithStyles = withStyles(({ color, units, font }) => ({
    button: {
        background: color.shadowWeaker,
        color: color.primary,
        appearance: 'none',
        borderWidth: 0,
        height: units(2.5),
        //minWidth: units(2.5),
        paddingTop: units(0.25),
        paddingRight: units(1.25),
        paddingBottom: units(0.25),
        paddingLeft: units(1.25),
        fontSize: units(0.95),
        outline: 0,
        position: 'relative',
        marginRight: .5,
        marginBottom: 0,
        marginLeft: .5,
        fontWeight: 500,
        fontFamily: font.default,
        boxSizing: 'border-box',
        overflow: 'hidden',
        cursor: 'pointer',

        ':hover': {
            background: color.shadowWeakest
        }
    },

    button_fullWidth: {
        width: '100%'
    },

    button_loading: {
        opacity: 1,
        pointerEvents: 'none'
    },

    button_underlined: {
        borderBottomWidth: 1,
        borderBottomColor: color.primary,
        borderBottomStyle: 'solid'
    },

    button_disabled: {
        opacity: .5,
        pointerEvents: 'none'
    },

    button_mono: {
        backgroundColor: color.transparent,
        borderColor: color.black,
        borderWidth: 1,
        borderStyle: 'solid',
        color: color.black,
    },

    button_primary: {
        backgroundColor: color.primary,
    },

    button_secondary: {
        backgroundColor: color.transparent,
        borderColor: color.secondary,
        borderWidth: 1,
        borderStyle: 'solid',
        color: color.secondary,
    },

    button_inverse: {
        backgroundColor: color.white,
        color: color.primary,
        borderWidth: 0,
    },

    button_active: {
        background: color.transparent,
        cursor: 'default',

        ':hover': {
            background: color.transparent
        }
    },

    button_noBorder: {
        border: 'none',
        borderWidth: 0
    },

    button__content: {
        display: 'flex',
        alignItems: 'center',
        justifyContent: 'flex-start',
        opacity: 1,
        transition: 'opacity .2s',
        whiteSpace: 'nowrap',
        userSelect: 'none'
    },

    button__content_fullWidth: {
        justifyContent: 'center'
    },

    button__content_loading: {
        opacity: 0,
    },

    button__loader: {
        position: 'absolute',
        top: 0,
        right: 0,
        bottom: 0,
        left: 0,
        display: 'flex',
        alignItems: 'center',
        justifyContent: 'center'
    },

    shimmer: {
        position: 'absolute',
        width: '100%',
        height: '100%',
        top: 0,
        right: 0,
        bottom: 0,
        left: 0
    }

}))(TabButton);
export default TabButtonWithStyles
