import React, { Component } from 'react'
import TabButtonComponent from './TabButton'

const TabContext = React.createContext(
    {
        activeTab: null,
        setActiveTab: () => {}
    }
);

class Tabs extends Component {
    constructor(props) {
        super(props);

        this.setActiveTab = tab => {
            this.setState({ activeTab: tab })
        }

        this.state = {
            activeTab: null,
            setActiveTab: this.setActiveTab
        }
    }

    componentDidMount() {
        const { initialTab } = this.props;

        if(initialTab != null) {
            this.setActiveTab(initialTab)
        }
    }

    render() {
        const { children } = this.props;

        return (
            <TabContext.Provider value={this.state}>
                { children }
            </TabContext.Provider>
        )
    }
}

const Tab = ({ children, tabKey }) => (
    <TabContext.Consumer>
        {({ activeTab }) => tabKey === activeTab && children}
    </TabContext.Consumer>
)

const TabButton = ({ children, tabKey, ...props }) => (
    <TabContext.Consumer>
        {({ activeTab, setActiveTab }) => (
            <TabButtonComponent onClick={() => setActiveTab(tabKey)} active={tabKey === activeTab} {...props}>
                { children }
            </TabButtonComponent>
        )}
    </TabContext.Consumer>
)

export { Tabs, Tab, TabButton }
