import React from 'react'
import PropTypes from 'prop-types'
import { css, withStyles } from '../helpers/withStyles'
import { withStylesPropTypes } from 'react-with-styles'
import Shimmer from './Shimmer'

const propTypes = {
    ...withStylesPropTypes,
    bold: PropTypes.bool,
    collapsed: PropTypes.bool,
    disabled: PropTypes.bool,
    error: PropTypes.bool,
    inline: PropTypes.bool,
    inverse: PropTypes.bool,
    loading: PropTypes.bool,
    large: PropTypes.bool,
    light: PropTypes.bool,
    micro: PropTypes.bool,
    muted: PropTypes.bool,
    small: PropTypes.bool,
    short: PropTypes.bool,
    shimmerHeight: PropTypes.string,
    shimmerWidth: PropTypes.string,
    children: PropTypes.any
};

const Text = (
    {
        children,
        collapsed,
        bold,
        disabled,
        error,
        inline,
        inverse,
        loading,
        large,
        light,
        micro,
        muted,
        short,
        shimmerHeight,
        shimmerWidth,
        small,
        styles

    }
) => {
    if(small) {
        return (
            <small {...css(
                styles.text,
                bold        && styles.text_bold,
                collapsed    && styles.text_collapsed,
                disabled    && styles.text_disabled,
                error       && styles.text_error,
                inverse     && styles.text_inverse,
                large       && styles.text_large,
                light       && styles.text_light,
                micro       && styles.text_micro,
                muted       && styles.text_muted,
                short       && styles.text_short,
                small       && styles.text_small,
                inline     && styles.text_inline

            )}>
                { loading ? <Shimmer height={shimmerHeight || '1ex'} width={shimmerWidth || '60%'} /> : children }
            </small>
        )
    } else if(inline) {
        return (
            <span {...css(
                styles.text,
                !loading    && styles.text_inline,
                bold        && styles.text_bold,
                collapsed    && styles.text_collapsed,
                error       && styles.text_error,
                disabled    && styles.text_disabled,
                inverse     && styles.text_inverse,
                large       && styles.text_large,
                light       && styles.text_light,
                micro       && styles.text_micro,
                muted       && styles.text_muted,
                short       && styles.text_short,
                small       && styles.text_small,

            )}>
                { loading ? <Shimmer height={shimmerHeight || '1ex'} width={shimmerWidth || '60%'} /> : children }
            </span>
        )
    }
    return (
        <p {...css(
            styles.text,
            bold        && styles.text_bold,
            collapsed    && styles.text_collapsed,
            disabled    && styles.text_disabled,
            error       && styles.text_error,
            inverse     && styles.text_inverse,
            large       && styles.text_large,
            light       && styles.text_light,
            micro       && styles.text_micro,
            muted       && styles.text_muted,
            short       && styles.text_short,
            small       && styles.text_small,
            inline      && styles.text_inline

        )}
        >
            { loading ? <Shimmer height="1ex" width="60%" /> : children }
        </p>
    )
};

Text.propTypes = propTypes;

const TextWithStyles = withStyles(({ units, color, weight, fontSize, lineHeight, font, breakpoint }) => ({
    text: {
        wordWrap: 'break-word',
        letterSpacing: 'normal',
        fontFamily: font.default,
        color: color.grayDarker,
        fontWeight: weight.normal,
        fontSize: fontSize.small.regular,
        lineHeight: lineHeight.regular,
        margin: 0,
        padding: 0,
        display: 'block',

        [breakpoint.large]: {
            fontSize: fontSize.large.regular
        }
    },

    text_bold: {
        fontWeight: weight.bold
    },

    text_collapsed: {
        whiteSpace: 'nowrap',
        overflow: 'hidden',
        textOverflow: 'ellipsis'
    },

    text_disabled: {
        opacity: .5
    },

    text_error: {
        color: color.alertDark
    },

    text_inverse: {
        color: color.white
    },

    text_large: {
        fontSize: fontSize.small.large,

        [breakpoint.large]: {
            fontSize: fontSize.large.large
        }
    },

    text_light: {
        fontWeight: weight.light
    },

    text_micro: {
        fontSize: fontSize.small.micro,

        [breakpoint.large]: {
            fontSize: fontSize.large.micro
        }
    },

    text_muted: {
        color: color.blueGrayDark
    },

    text_short: {
        lineHeight: lineHeight.short
    },

    text_small: {
        fontSize: fontSize.small.small,

        [breakpoint.large]: {
            fontSize: fontSize.large.small
        }
    },

    text_inline: {
        display: 'inline-block'
    }

}))(Text);

export default TextWithStyles
