import React from 'react'
import PropTypes from 'prop-types'
import FormElement from './FormElement'
import TextAreaOnly from './TextAreaOnly'

const propTypes = {
    actionLink: PropTypes.string,
    compact: PropTypes.bool,
    borderless: PropTypes.bool,
    disabled: PropTypes.bool,
    errorMessage: PropTypes.any,
    extraPadding: PropTypes.bool,
    focusBorderless: PropTypes.bool,
    hideLabel: PropTypes.bool,
    id: PropTypes.string,
    inline: PropTypes.bool,
    invalid: PropTypes.bool,
    inverse: PropTypes.bool,
    label: PropTypes.string,
    labelDescription: PropTypes.string,
    large: PropTypes.bool,
    lightLabel: PropTypes.bool,
    maxLength: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
    minRows: PropTypes.number,
    name: PropTypes.string.isRequired,
    onBlur: PropTypes.func,
    onChange: PropTypes.func,
    onFocus: PropTypes.func,
    placeholder: PropTypes.string,
    readOnly: PropTypes.bool,
    removeMargins: PropTypes.bool,
    showCount: PropTypes.bool,
    showFakeValuePlaceholder: PropTypes.bool,
    showOverflowEllipsis: PropTypes.bool,
    small: PropTypes.bool,
    value: PropTypes.string
};

const TextArea = (
    {
        actionLink,
        compact,
        borderless,
        disabled,
        errorMessage,
        extraPadding,
        focusBorderless,
        hideLabel,
        id,
        inline,
        invalid,
        inverse,
        label,
        labelDescription,
        large,
        lightLabel,
        maxLength,
        minRows,
        name,
        onBlur,
        onChange,
        onFocus,
        placeholder,
        readOnly,
        removeMargins,
        showCount,
        showFakeValuePlaceholder,
        showOverflowEllipsis,
        small,
        value
    }
) => {
    return (
        <FormElement
            actionLink={actionLink}
            errorMessage={errorMessage}
            hideLabel={hideLabel}
            id={id}
            inline={inline}
            invalid={invalid}
            inverse={inverse}
            label={label}
            labelDescription={labelDescription}
            large={large}
            lightLabel={lightLabel}
            small={small}
        >
            <TextAreaOnly
                borderless={borderless}
                compact={compact}
                disabled={disabled}
                extraPadding={extraPadding}
                focusBorderless={focusBorderless}
                id={id}
                inline={inline}
                invalid={invalid}
                inverse={inverse}
                large={large}
                maxLength={maxLength}
                minRows={minRows}
                name={name}
                onBlur={onBlur}
                onChange={onChange}
                onFocus={onFocus}
                placeholder={placeholder}
                readOnly={readOnly}
                removeMargins={removeMargins}
                showCount={showCount}
                showFakeValuePlaceholder={showFakeValuePlaceholder}
                showOverflowEllipsis={showOverflowEllipsis}
                small={small}
                value={value}
            />
        </FormElement>
    )
};

TextArea.propTypes = propTypes;

export default TextArea

