import React from 'react'
import PropTypes from 'prop-types'
import Shimmer from './Shimmer'
import { withStylesPropTypes } from 'react-with-styles'
import { withStyles } from '../helpers/withStyles'

const propTypes = {
    ...withStylesPropTypes,
    actionLink: PropTypes.string,
    compact: PropTypes.bool,
    borderless: PropTypes.bool,
    disabled: PropTypes.bool,
    focusBorderless: PropTypes.bool,
    id: PropTypes.string,
    inline: PropTypes.bool,
    invalid: PropTypes.bool,
    inverse: PropTypes.bool,
    large: PropTypes.bool,
    maxLength: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
    minRows: PropTypes.number,
    name: PropTypes.string.isRequired,
    onBlur: PropTypes.func,
    onChange: PropTypes.func,
    onFocus: PropTypes.func,
    placeholder: PropTypes.string,
    readOnly: PropTypes.bool,
    removeMargins: PropTypes.bool,
    shimmer: PropTypes.bool,
    showCount: PropTypes.bool,
    showFakeValuePlaceholder: PropTypes.bool,
    showOverflowEllipsis: PropTypes.bool,
    small: PropTypes.bool,
    value: PropTypes.string
};

const defaultProps = {
    minRows: 4,
};

const TextAreaOnly = (
    {
        actionLink,
        compact,
        borderless,
        css,
        disabled,
        extraPadding,
        focusBorderless,
        id,
        inline,
        invalid,
        inverse,
        large,
        maxLength,
        minRows,
        name,
        onBlur,
        onChange,
        onFocus,
        placeholder,
        readOnly,
        removeMargins,
        shimmer,
        showCount,
        showFakeValuePlaceholder,
        showOverflowEllipsis,
        small,
        styles,
        value
    }
) => {
    return (
        <div
            {...css(
                styles.textAreaOnly,
                !inline && styles.block,
                borderless && styles.borderless,
                disabled && styles.textAreaOnly_disabled,
                invalid && styles.textAreaOnly_invalid,
                small && styles.textAreaOnly_small,
                removeMargins && styles.textAreaOnly_noMargin,
            )}
        >
            {
                shimmer && <div {...css(styles.shimmer)}><Shimmer width="100%" height="100%"/></div>
            }
            <textarea
                {...css(
                    styles.textAreaOnly__input,
                    extraPadding && styles.textAreaOnly__input_extraPadding,
                    showOverflowEllipsis && styles.textAreaOnly__input_ellipsis,
                    showFakeValuePlaceholder ? styles.textAreaOnly__input_fakeValuePlaceholder : styles.textAreaOnly__input_defaultPlaceholder,
                )}
                disabled={disabled}
                id={id}
                maxLength={maxLength}
                name={name}
                onBlur={onBlur}
                onChange={onChange}
                onFocus={onFocus}
                placeholder={placeholder}
                value={value}
                readOnly={readOnly}
                aria-readonly={readOnly}
            />
        </div>
    )
};

TextAreaOnly.propTypes = propTypes;
TextAreaOnly.defaultProps = defaultProps;

const TextAreaOnlyWithStyles = withStyles(({ input, color, units }) => ({
    textAreaOnly: {
        ...input.default,
        display: 'inline-flex',
        position: 'relative',
        zIndex: 0,
        flexWrap: 'nowrap',
        alignItems: 'center',

        ':focus-within': {
            ...input.focus
        }
    },

    textAreaOnly_disabled: {
        ...input.disabled
    },

    textAreaOnly_invalid: {
        ...input.invalid
    },

    textAreaOnly_small: {
        ...input.small
    },

    textAreaOnly_noMargin: {
        marginTop: 0,
        marginRight: 0,
        marginBottom: 0,
        marginLeft: 0
    },

    textAreaOnly__input: {
        ...input.default,
        border: 0,
        margin: 0,
        background: color.transparent,
        width: '100%',
        height: 'auto',
        paddingTop: input.verticalPadding,
        paddingRight: input.horizontalPadding,
        paddingBottom: input.verticalPadding,
        paddingLeft: input.horizontalPadding,
        boxSizing: 'border-box',

        '::-ms-clear': {
            display: 'none'
        },

        ':focus': {
            outline: 'none',
            boxShadow: 'none',
            border: 0,
        },
    },

    textAreaOnly__input_extraPadding: {

    },

    textAreaOnly__input_ellipsis: {
        textOverflow: 'ellipsis'
    },

    textAreaOnly__input_defaultPlaceholder: {
        '::placeholder': {
            color: input.placeholderColor,
            opacity: 1
        }
    },

    textAreaOnly__input_fakeValuePlaceholder: {
        '::placeholder': {
            color: input.color,
            opacity: 1
        }
    },

    textAreaOnly__input_inversePlaceholder: {
        '::placeholder': {
            color: color.white,
            opacity: 1
        }
    },

    block: {
        display: 'flex',
        width: '100%'
    },

    borderless: {
        borderColor: input.background
    },

    shimmer: {
        position: 'absolute',
        width: '100%',
        height: '100%',
        top: 0,
        right: 0,
        bottom: 0,
        left: 0
    }
}))(TextAreaOnly);

export default TextAreaOnlyWithStyles

