import React, { Component } from 'react'
import PropTypes from 'prop-types'
import _ from 'lodash'

const propTypes = {
    children: PropTypes.object.isRequired,
    debounceTimeoutMs: PropTypes.number,
    debouncedOnChange: PropTypes.func,
    throttleTimeoutMs: PropTypes.number,
    throttledOnChange: PropTypes.func,
};

class ThrottledTextInput extends Component {
    constructor(props) {
        super(props);

        this.onChange = this.onChange.bind(this);
        this.debouncedOnChange = _.debounce(this.debouncedOnChange.bind(this), props.debounceTimeoutMs);
        this.throttledOnChange = _.throttle(this.throttledOnChange.bind(this), props.throttleTimeoutMs);
    }

    debouncedOnChange(value) {
        this.props.debouncedOnChange(value)
    }

    throttledOnChange(value) {
        this.props.throttledOnChange(value)
    }

    onChange(event) {
        const { value } = event.target;
        const { debounceTimeoutMs, debouncedOnChange, throttleTimeoutMs, throttledOnChange } = this.props;
        if(debouncedOnChange && debounceTimeoutMs) {
            this.debouncedOnChange(value)
        } else if(throttledOnChange && throttleTimeoutMs) {
            this.throttledOnChange(value)
        }
    }

 render() {
     const { children } = this.props;

         return (
             React.cloneElement(React.Children.only(children), {
                 onChange: this.onChange
             })
         )
     }
 }

 ThrottledTextInput.propTypes = propTypes;

export default ThrottledTextInput
