import React from 'react'
import PropTypes from 'prop-types'
import { css, withStyles } from '../helpers/withStyles'
import { withStylesPropTypes } from 'react-with-styles'
import Shimmer from './Shimmer'

const propTypes = {
    ...withStylesPropTypes,
    inline: PropTypes.bool,
    inverse: PropTypes.bool,
    loading: PropTypes.bool,
    level: PropTypes.oneOf([1,2,3]),
    light: PropTypes.bool,
    muted: PropTypes.bool,
    noBottomSpacing: PropTypes.bool,
    noSpacing: PropTypes.bool,
    noTopSpacing: PropTypes.bool,
    title: PropTypes.string,
    truncate: PropTypes.bool,
    shimmerWidth: PropTypes.string,
    children: PropTypes.any
};

const defaultProps = {
    level: 1
};

const Title = (
    {
        children,
        inline,
        inverse,
        loading,
        level,
        light,
        muted,
        noBottomSpacing,
        noSpacing,
        noTopSpacing,
        title,
        truncate,
        shimmerWidth,
        styles

    }
) => {
    const content = () => {
        switch (level) {
            case 1: return <h1 {...css(styles.title__header)}>{ children ? children : title }</h1>;
            case 2: return <h2 {...css(styles.title__header)}>{ children ? children : title }</h2>;
            case 3: return <h3 {...css(styles.title__header)}>{ children ? children : title }</h3>;
            default: return <h1 {...css(styles.title__header)}>{ children ? children : title }</h1>;
        }
    };

    return (
        <div {...css(
            styles.title,
            inline      && styles.title_inline,
            inverse     && styles.title_inverse,
            level === 1 && styles.title_level1,
            level === 2 && styles.title_level2,
            level === 3 && styles.title_level3,
            light       && styles.title_light,
            muted       && styles.title_muted,
            (noTopSpacing || noSpacing) && styles.title_noTopSpacing,
            (noBottomSpacing || noSpacing) && styles.title_noBottomSpacing,
            truncate    && styles.title_truncate,
        )}>
            { loading ? <Shimmer height="1ex" width={shimmerWidth || '60%'} /> : content() }
        </div>
    )
};

Title.propTypes = propTypes;
Title.defaultProps = defaultProps;

const TitleWithStyles = withStyles(({ units, color, weight, fontSize, lineHeight, font, breakpoint }) => ({
    title: {
        wordWrap: 'break-word',
        letterSpacing: 'normal',
        fontFamily: font.default,
        color: color.grayDarker,
        fontWeight: weight.bold,
        lineHeight: lineHeight.short,
        margin: 0,
        paddingTop: units(0.5),
        paddingBottom: units(0.5),
        display: 'block'
    },

    title_inverse: {
        color: color.white
    },

    title_level1: {
        fontSize: fontSize.small.title1,

        [breakpoint.large]: {
            fontSize: fontSize.large.title1
        }
    },

    title_level2: {
        fontSize: fontSize.small.title2,

        [breakpoint.large]: {
            fontSize: fontSize.large.title2
        }
    },

    title_level3: {
        fontSize: fontSize.small.title3,

        [breakpoint.large]: {
            fontSize: fontSize.large.title3
        }
    },

    title_light: {
        fontWeight: weight.light
    },

    title_muted: {
        color: color.blueGrayDark
    },

    title_noBottomSpacing: {
        paddingBottom: 0
    },

    title_noTopSpacing: {
        paddingTop: 0
    },

    title_truncate: {
        whiteSpace: 'nowrap',
        overflow: 'hidden',
        textOverflow: 'ellipsis'
    },

    title_inline: {
        display: 'inline-block'
    },

    title__header: {
        fontSize: '1em',
        lineHeight: 'inherit',
        fontWeight: 'inherit',
        color: 'inherit',
        margin: 0,
        padding: 0,
        display: 'flex',
        alignItems: 'center'
    }

}))(Title);

export default TitleWithStyles
