import React from 'react'
import PropTypes from 'prop-types'
import { withStyles } from '../helpers/withStyles'
import { withStylesPropTypes } from 'react-with-styles'

const propTypes = {
    ...withStylesPropTypes,
    container: PropTypes.bool,
    fullHeight: PropTypes.bool,
    gray: PropTypes.bool,
    smallContainer: PropTypes.bool,
    microContainer: PropTypes.bool,
    largeVerticalSpacing: PropTypes.bool,
    smallVerticalSpacing: PropTypes.bool,
    verticalSpacing: PropTypes.bool,
    largeSpacing: PropTypes.bool,
    smallSpacing: PropTypes.bool,
    noSpacing: PropTypes.bool,
    backgroundColor: PropTypes.string

};

const Wrapper = (
    {
        container,
        fullHeight,
        gray,
        smallContainer,
        microContainer,
        largeVerticalSpacing,
        smallVerticalSpacing,
        verticalSpacing,
        largeSpacing,
        smallSpacing,
        noSpacing,
        backgroundColor,
        styles,
        css,
        children,
    }
) => (
    <div
        {...css(
            styles.wrapper,
            container && styles.wrapper_container,
            fullHeight && styles.wrapper_fullHeight,
            gray && styles.wrapper_gray,
            largeVerticalSpacing && styles.wrapper_verticalSpacingLarge,
            smallVerticalSpacing && styles.wrapper_verticalSpacingSmall,
            verticalSpacing && styles.wrapper_verticalSpacing,
            largeSpacing && styles.wrapper_spacingLarge,
            smallSpacing && styles.wrapper_spacingSmall,
            noSpacing && styles.wrapper_noSpacing,
            { backgroundColor }
        )}
    >
        { children }
    </div>
);

Wrapper.propTypes = propTypes;

const PageWrapperWithStyles = withStyles(({ color, units, breakpoint, container }) => ({
    wrapper: {
        boxSizing: 'border-box',
        paddingLeft: units(1.5),
        paddingRight: units(1.5),
        width: '100%',

        [breakpoint.large]: {
            paddingLeft: units(4),
            paddingRight: units(4),
        }
    },

    wrapper_container: {
        maxWidth: container.default,
        marginLeft: 'auto',
        marginRight: 'auto',
        alignSelf: 'center'
    },

    wrapper_fullHeight: {
        height: '100%'
    },

    wrapper_gray: {
        background: color.grayLight,
    },

    wrapper_spacingLarge: {
        paddingLeft: units(3),
        paddingRight: units(3),

        [breakpoint.large]: {
            paddingLeft: units(6),
            paddingRight: units(6),
        }
    },

    wrapper_spacingSmall: {
        paddingLeft: units(1),
        paddingRight: units(1),

        [breakpoint.large]: {
            paddingLeft: units(3),
            paddingRight: units(3),
        }
    },

    wrapper_verticalSpacing: {
        paddingTop: units(2.5),
        paddingBottom: units(2.5),
    },

    wrapper_verticalSpacingLarge: {
        paddingTop: units(5),
        paddingBottom: units(5),
    },

    wrapper_verticalSpacingSmall: {
        paddingTop: units(1),
        paddingBottom: units(1),
    },

    wrapper_noSpacing: {
        paddingTop: 0,
        paddingLeft: 0,
        paddingBottom: 0,
        paddingRight: 0,

        [breakpoint.large]: {
            paddingTop: 0,
            paddingLeft: 0,
            paddingBottom: 0,
            paddingRight: 0,
        }
    },

}))(Wrapper);

export default PageWrapperWithStyles
